(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     15468,        392]
NotebookOptionsPosition[     14881,        367]
NotebookOutlinePosition[     15223,        382]
CellTagsIndexPosition[     15180,        379]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Example 3.3.3", "Subtitle",
 CellChangeTimes->{{3.485014085164942*^9, 3.4850140875123796`*^9}}],

Cell["\<\
This notebook contains a manipulation which illustrates example 3.3.3 from \
the text, showing how the solution to a near-parallel system of lines changes \
as one of the coefficients changes.  Specifically it shows the solution to \
the system\
\>", "Text",
 CellChangeTimes->{{3.485014113780924*^9, 3.485014191532332*^9}, {
  3.48501422791003*^9, 3.485014268508576*^9}},
 TextAlignment->Left],

Cell[TextData[Cell[BoxData[
 FormBox[GridBox[{
    {GridBox[{
       {
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{".23671", "x"}], "+", "y"}], "=", ".00633"}], 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{".23647", "+", "R"}], ")"}], "x"}], "+", "y"}], "=", 
          ".04353"}]}]}
      },
      GridBoxAlignment->{"Columns" -> {{"="}}}]}
   },
   GridBoxItemSize->{"Columns" -> {{
        Scaled[0.96]}}}], TraditionalForm]]]], "Text",
 CellChangeTimes->{{3.4850142775161*^9, 3.485014320446249*^9}}],

Cell[TextData[{
 "where the number R varies from 0 (representing a solution to the \
almost-parallel system   ",
 Cell[BoxData[
  FormBox[GridBox[{
     {
      RowBox[{
       RowBox[{
        RowBox[{".23671", "x"}], "+", "y"}], "=", ".00633"}], 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{".23647", "+", "R"}], ")"}], "x"}], "+", "y"}], "=", 
       ".04353"}]}
    }], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " ) to .00021.  A slider is provided to let you change the value of R over \
this range.  Two graphs are shown.  The left graphic shows the solution to \
the system when R=0 (in red) along with the solution to the system for the \
current value of R (in blue).  The right graphic shows you the grph of the \
distance between the two solutions as a function of R, along with a vertical \
line to display the current value of R from the slider."
}], "Text",
 CellChangeTimes->{{3.4850143280282784`*^9, 3.485014591736306*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SolutionPlot", "[", "r_", "]"}], ":=", " ", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "originalsolution", ",", "currentsolution", ",", "r1solution", ",", 
      "distance", ",", "pointgraphics", ",", "errorplot", ",", " ", 
      "pointplot", ",", "x", ",", "y", ",", "r1"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"r1solution", "=", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y"}], "}"}], "/.", " ", 
       RowBox[{
        RowBox[{"Solve", "[", " ", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"23671", "/", "100000"}], "x"}], "+", "y"}], 
             "\[Equal]", 
             RowBox[{"633", "/", "100000"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"23647", "/", "100000"}], "+", "r1"}], ")"}], "x"}], 
              "+", "y"}], "\[Equal]", 
             RowBox[{"4353", "/", "100000"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "y"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"originalsolution", "=", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y"}], "}"}], "/.", 
       RowBox[{
        RowBox[{"Solve", "[", " ", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"23671", "/", "100000"}], "x"}], "+", "y"}], 
             "\[Equal]", 
             RowBox[{"633", "/", "100000"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"23647", "/", "100000"}], ")"}], "x"}], "+", "y"}], 
             "\[Equal]", 
             RowBox[{"4353", "/", "100000"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "y"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"currentsolution", "=", 
      RowBox[{"r1solution", "/.", " ", 
       RowBox[{"r1", "\[Rule]", "r"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"distance", "=", 
      RowBox[{"Norm", "[", 
       RowBox[{"r1solution", "-", "originalsolution"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"pointgraphics", "=", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"PointSize", "[", ".04", "]"}], ",", "Red", ",", " ", 
         RowBox[{"Point", "[", "originalsolution", "]"}], ",", "Blue", ",", 
         RowBox[{"Point", "[", "currentsolution", "]"}], ",", " ", "Green", 
         ",", " ", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{"originalsolution", ",", " ", "currentsolution"}], "}"}], 
          "]"}]}], "}"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"errorplot", "=", 
      RowBox[{"Show", "[", " ", 
       RowBox[{
        RowBox[{"Plot", "[", " ", 
         RowBox[{"distance", ",", 
          RowBox[{"{", 
           RowBox[{"r1", ",", "0", ",", ".00021"}], "}"}], ",", " ", 
          RowBox[{"PlotRange", "\[Rule]", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", ".00021"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "900"}], "}"}]}], "}"}]}], ",", " ", 
          RowBox[{"Axes", "\[Rule]", "False"}], ",", " ", 
          RowBox[{"Frame", "\[Rule]", " ", "True"}], ",", " ", 
          RowBox[{"FrameLabel", "\[Rule]", " ", 
           RowBox[{"{", 
            RowBox[{
            "\"\<R\>\"", ",", " ", 
             "\"\<distance between the two solutions\>\""}], "}"}]}], ",", 
          " ", 
          RowBox[{"Ticks", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{".001", " ", 
              RowBox[{"Range", "[", "4", "]"}]}], ",", " ", 
             RowBox[{"50", " ", 
              RowBox[{"Range", "[", "5", "]"}]}]}], "}"}]}]}], "]"}], ",", 
        " ", 
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"r", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"r", ",", "900"}], "}"}]}], "}"}], "]"}], "}"}], "]"}], 
        ",", " ", 
        RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"pointplot", "=", 
      RowBox[{"Show", "[", 
       RowBox[{"pointgraphics", ",", " ", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1000"}], ",", 
             RowBox[{"-", "150"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "250"}], "}"}]}], "}"}]}], ",", " ", 
        RowBox[{"Axes", "\[Rule]", "True"}], ",", "  ", 
        RowBox[{"AxesLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"x", ",", "y"}], "}"}]}], ",", " ", 
        RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"ImageSize", "\[Rule]", "250"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Return", "[", " ", 
      RowBox[{"Show", "[", 
       RowBox[{"GraphicsArray", "[", " ", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Show", "[", 
            RowBox[{"pointplot", ",", " ", 
             RowBox[{"AxesOrigin", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1000"}], ",", "0"}], "}"}]}]}], "]"}], ",", 
           "errorplot"}], "}"}], "}"}], "]"}], "]"}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellOpen->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Manipulate", "[", 
   RowBox[{
    RowBox[{"SolutionPlot", "[", "r", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"r", ",", "0"}], "}"}], ",", "0", ",", ".00021", ",", 
      ".000001"}], "}"}], ",", " ", 
    RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.482235928944948*^9, 3.482235932140355*^9}, {
   3.4822367028400803`*^9, 3.482236774224818*^9}, {3.4822390673251743`*^9, 
   3.4822391095334806`*^9}, {3.482239139567227*^9, 3.482239229086825*^9}, {
   3.482239302321163*^9, 3.482239318663224*^9}, {3.482239351665147*^9, 
   3.482239354503399*^9}, {3.482239391617526*^9, 3.482239396311355*^9}, {
   3.482239440993352*^9, 3.482239444543551*^9}, 3.482239531761567*^9, {
   3.482239796962091*^9, 3.4822397990002317`*^9}, 3.482240043009038*^9, {
   3.482240120280416*^9, 3.482240237455039*^9}, {3.4822404448027287`*^9, 
   3.4822404623933372`*^9}, {3.485013527500198*^9, 3.485013549932602*^9}, 
   3.4850138107016697`*^9, {3.4850138582137547`*^9, 3.485013898041781*^9}, {
   3.4850139824544573`*^9, 3.485013984420825*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`r$$ = 0., Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`r$$], 0}, 0, 0.00021, 1.*^-6}}, Typeset`size$$ = {
    682., {168., 175.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`r$66857$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`r$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`r$$, $CellContext`r$66857$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`SolutionPlot[$CellContext`r$$], 
      "Specifications" :> {{{$CellContext`r$$, 0}, 0, 0.00021, 1.*^-6}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{735., {239.21875, 245.78125}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`SolutionPlot[
         Pattern[$CellContext`r, 
          Blank[]]] := 
       Block[{$CellContext`originalsolution, $CellContext`currentsolution, \
$CellContext`r1solution, $CellContext`distance, $CellContext`pointgraphics, \
$CellContext`errorplot, $CellContext`pointplot, $CellContext`x, \
$CellContext`y, $CellContext`r1}, $CellContext`r1solution = 
          ReplaceAll[{$CellContext`x, $CellContext`y}, 
            Part[
             
             Solve[{(23671/100000) $CellContext`x + $CellContext`y == 
               633/100000, (
                  23647/100000 + $CellContext`r1) $CellContext`x + \
$CellContext`y == 4353/100000}, {$CellContext`x, $CellContext`y}], 
             1]]; $CellContext`originalsolution = 
          ReplaceAll[{$CellContext`x, $CellContext`y}, 
            Part[
             
             Solve[{(23671/100000) $CellContext`x + $CellContext`y == 
               633/100000, (23647/100000) $CellContext`x + $CellContext`y == 
               4353/100000}, {$CellContext`x, $CellContext`y}], 
             1]]; $CellContext`currentsolution = 
          ReplaceAll[$CellContext`r1solution, $CellContext`r1 -> \
$CellContext`r]; $CellContext`distance = 
          Norm[$CellContext`r1solution - $CellContext`originalsolution]; \
$CellContext`pointgraphics = Graphics[{
             PointSize[0.04], Red, 
             Point[$CellContext`originalsolution], Blue, 
             Point[$CellContext`currentsolution], Green, 
             
             Line[{$CellContext`originalsolution, \
$CellContext`currentsolution}]}]; $CellContext`errorplot = Show[
            
            Plot[$CellContext`distance, {$CellContext`r1, 0, 0.00021}, 
             PlotRange -> {{0, 0.00021}, {0, 900}}, Axes -> False, Frame -> 
             True, FrameLabel -> {"R", "distance between the two solutions"}, 
             Ticks -> {0.001 Range[4], 50 Range[5]}], 
            Graphics[{
              Line[{{$CellContext`r, 0}, {$CellContext`r, 900}}]}], 
            AspectRatio -> 1]; $CellContext`pointplot = 
          Show[$CellContext`pointgraphics, 
            PlotRange -> {{-1000, -150}, {0, 250}}, Axes -> True, 
            AxesLabel -> {$CellContext`x, $CellContext`y}, AspectRatio -> 1, 
            ImageSize -> 250]; Return[
           Show[
            GraphicsArray[{{
               
               Show[$CellContext`pointplot, 
                AxesOrigin -> {-1000, 0}], $CellContext`errorplot}}]]]]}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.482235933076157*^9, 3.482235987554154*^9}, {
   3.4822360342406673`*^9, 3.48223605687638*^9}, 3.48223609580343*^9, 
   3.482236183847649*^9, 3.482236227589872*^9, 3.482236318374557*^9, 
   3.482236364019071*^9, 3.482236432088645*^9, 3.482236477924862*^9, 
   3.482236516217744*^9, 3.482236593240745*^9, 3.482236676954048*^9, 
   3.482236716657349*^9, 3.4822367482605553`*^9, {3.482239220826274*^9, 
   3.482239229658257*^9}, 3.4822393206759167`*^9, 3.482239355253504*^9, 
   3.4822393979976377`*^9, 3.482239445175424*^9, 3.4822395318600082`*^9, 
   3.482239661190106*^9, 3.482239699071706*^9, {3.482239770684269*^9, 
   3.482239799999468*^9}, 3.482239904802918*^9, 3.482239938453207*^9, {
   3.482240120956259*^9, 3.482240237890576*^9}, {3.482240450502624*^9, 
   3.4822404631350946`*^9}, {3.485013530417862*^9, 3.485013551239718*^9}, 
   3.48501363810739*^9, 3.485013812058865*^9, {3.485013865528451*^9, 
   3.4850139215204353`*^9}, 3.4850139848329983`*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{881, 678},
WindowMargins->{{103, Automatic}, {Automatic, 191}},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 101, 1, 57, "Subtitle"],
Cell[671, 25, 404, 8, 51, "Text"],
Cell[1078, 35, 625, 20, 55, "Text"],
Cell[1706, 57, 996, 24, 109, "Text"],
Cell[2705, 83, 5932, 157, 23, "Input",
 CellOpen->False],
Cell[CellGroupData[{
Cell[8662, 244, 1177, 22, 23, "Input",
 CellOpen->False],
Cell[9842, 268, 5011, 95, 505, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
