(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     17291,        440]
NotebookOptionsPosition[     16568,        410]
NotebookOutlinePosition[     16910,        425]
CellTagsIndexPosition[     16867,        422]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Example 4.2.1", "Subtitle",
 CellChangeTimes->{{3.481626328322345*^9, 3.48162633044812*^9}}],

Cell["\<\
This notebook simulates Example 4.2.1 in the text, which discusses finding \
the best-fitting parabola through 3 points P, Q, and R.  In the window below \
you may move around the points P, Q, and R by dragging them.  The coordinates \
of the points will automatically update as will the graph of the best-fitting \
parabola.  The manipulation does do a check for the rare case of when the \
points are collinear.  A second manipulation is also included which allows \
you to enter exact coordinates for the points instead of letting you drag \
them around.  No evaluation is required to make either work.\
\>", "Text",
 CellChangeTimes->{{3.481626349625149*^9, 3.481626522289131*^9}, {
  3.481626605539681*^9, 3.4816266359705133`*^9}, {3.481626901095441*^9, 
  3.481626938014619*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Example421", "[", 
   RowBox[{"pt1_", ",", "pt2_", ",", "pt3_"}], "]"}], ":=", 
  RowBox[{"Block", "[", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "parabola", ",", " ", "rawgraphics", ",", " ", "plot", ",", " ", 
      "ptlist", ",", "x"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Det", "[", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Join", "[", 
            RowBox[{
             RowBox[{"{", "1", "}"}], ",", "pt1"}], "]"}], ",", 
           RowBox[{"Join", "[", 
            RowBox[{
             RowBox[{"{", "1", "}"}], ",", "pt2"}], "]"}], ",", 
           RowBox[{"Join", "[", 
            RowBox[{
             RowBox[{"{", "1", "}"}], ",", "pt3"}], "]"}]}], "}"}], "]"}], 
        "\[Equal]", "0"}], ",", " ", 
       RowBox[{"Return", "[", " ", 
        RowBox[{"Plot", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", 
            RowBox[{"-", "30"}], ",", "50"}], "}"}], ",", " ", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "20"}], ",", "50"}], "}"}]}], ",", " ", 
          RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", " ", 
          RowBox[{
          "PlotLabel", "\[Rule]", " ", 
           "\"\<There is no parabola fitting these points\>\""}]}], "]"}], 
        "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"parabola", "=", 
      RowBox[{"LinearModelFit", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"pt1", ",", "pt2", ",", "pt3"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"1", ",", " ", "x", ",", " ", 
          RowBox[{"x", "^", "2"}]}], "}"}], ",", "x"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"rawgraphics", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"\"\<P\>\"", ",", "pt1", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "3"}], "}"}]}], "]"}], ",", " ", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<Q\>\"", ",", "pt2", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "3"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<R\>\"", ",", " ", "pt3", ",", " ", 
          RowBox[{"{", 
           RowBox[{"0", ",", "3"}], "}"}]}], "]"}], ",", 
        RowBox[{"PointSize", "[", ".02", "]"}], ",", " ", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{"pt1", ",", "pt2", ",", "pt3"}], "}"}], "]"}]}], "}"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"ptlist", "=", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<Point P\>\"", ",", " ", "\"\<Point Q\>\"", ",", " ", 
          "\"\<Point R\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "pt1", "}"}], ",", 
          RowBox[{"{", "pt2", "}"}], ",", 
          RowBox[{"{", "pt3", "}"}]}], "}"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Return", "[", 
      RowBox[{"Column", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"TableForm", "[", "ptlist", "]"}], ",", " ", 
          RowBox[{"Show", "[", 
           RowBox[{
            RowBox[{"Plot", "[", 
             RowBox[{
              RowBox[{"parabola", "[", "x", "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"x", ",", 
                RowBox[{"-", "30"}], ",", "50"}], "}"}], ",", " ", 
              RowBox[{"PlotRange", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "20"}], ",", "50"}], "}"}]}], ",", " ", 
              RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", " ", 
              RowBox[{"PlotLabel", "\[Rule]", " ", 
               RowBox[{"parabola", "[", "x", "]"}]}]}], "]"}], ",", 
            RowBox[{"Graphics", "[", "rawgraphics", "]"}], ",", " ", 
            RowBox[{"ImageSize", "\[Rule]", "350"}]}], "]"}]}], "}"}], ",", 
        " ", 
        RowBox[{"Alignment", "\[Rule]", "Center"}]}], "]"}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.48162510733845*^9, 3.48162512727181*^9}, {
  3.4816251775633087`*^9, 3.4816252079863567`*^9}, {3.481625238228676*^9, 
  3.481625552515995*^9}, {3.481625635652686*^9, 3.481625741477111*^9}, {
  3.481625817437936*^9, 3.4816258324702597`*^9}, {3.481625868808116*^9, 
  3.481625878438356*^9}, {3.4816259620417423`*^9, 3.481626098748699*^9}}],

Cell["Finding the parabola through draggable points:", "Text",
 CellChangeTimes->{{3.481626774189642*^9, 3.4816267889807*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", " ", 
  RowBox[{
   RowBox[{"Example421", "[", 
    RowBox[{"pt1", ",", "pt2", ",", "pt3"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pt1", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "21"}], ",", "17"}], "}"}]}], "}"}], ",", " ", 
     "Locator", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pt2", ",", 
       RowBox[{"{", 
        RowBox[{"9", ",", 
         RowBox[{"-", "6"}]}], "}"}]}], "}"}], ",", " ", "Locator", ",", " ", 
     
     RowBox[{"Appearance", "\[Rule]", "None"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pt3", ",", 
       RowBox[{"{", 
        RowBox[{"37", ",", "28"}], "}"}]}], "}"}], ",", " ", "Locator", ",", 
     " ", 
     RowBox[{"Appearance", "\[Rule]", "None"}]}], "}"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.481626127022244*^9, 3.481626267009568*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`pt1$$ = {-21, 17}, $CellContext`pt2$$ = {
    9, -6}, $CellContext`pt3$$ = {37, 28}, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`pt1$$], {-21, 17}}, Automatic}, {{
       Hold[$CellContext`pt2$$], {9, -6}}, Automatic}, {{
       Hold[$CellContext`pt3$$], {37, 28}}, Automatic}}, Typeset`size$$ = {
    438., {216.21875, 222.78125}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`pt1$$ = {-21, 17}, $CellContext`pt2$$ = {
         9, -6}, $CellContext`pt3$$ = {37, 28}}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`Example421[$CellContext`pt1$$, \
$CellContext`pt2$$, $CellContext`pt3$$], 
      "Specifications" :> {{{$CellContext`pt1$$, {-21, 17}}, Automatic, 
         ControlType -> Locator, Appearance -> 
         None}, {{$CellContext`pt2$$, {9, -6}}, Automatic, ControlType -> 
         Locator, Appearance -> None}, {{$CellContext`pt3$$, {37, 28}}, 
         Automatic, ControlType -> Locator, Appearance -> None}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{499., {255.21875, 261.78125}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`Example421[
         Pattern[$CellContext`pt1, 
          Blank[]], 
         Pattern[$CellContext`pt2, 
          Blank[]], 
         Pattern[$CellContext`pt3, 
          Blank[]]] := 
       Block[{$CellContext`parabola, $CellContext`rawgraphics, \
$CellContext`plot, $CellContext`ptlist, $CellContext`x}, If[Det[{
              Join[{1}, $CellContext`pt1], 
              Join[{1}, $CellContext`pt2], 
              Join[{1}, $CellContext`pt3]}] == 0, 
           Return[
            Plot[
            0, {$CellContext`x, -30, 50}, PlotRange -> {-20, 50}, AspectRatio -> 
             Automatic, PlotLabel -> 
             "There is no parabola fitting these points"]]]; \
$CellContext`parabola = 
          LinearModelFit[{$CellContext`pt1, $CellContext`pt2, \
$CellContext`pt3}, {
            1, $CellContext`x, $CellContext`x^2}, $CellContext`x]; \
$CellContext`rawgraphics = {
            Text["P", $CellContext`pt1, {0, 3}], 
            Text["Q", $CellContext`pt2, {0, 3}], 
            Text["R", $CellContext`pt3, {0, 3}], 
            PointSize[0.02], 
            
            Point[{$CellContext`pt1, $CellContext`pt2, $CellContext`pt3}]}; \
$CellContext`ptlist = {{
            "Point P", "Point Q", 
             "Point R"}, {{$CellContext`pt1}, {$CellContext`pt2}, \
{$CellContext`pt3}}}; Return[
           Column[{
             TableForm[$CellContext`ptlist], 
             Show[
              Plot[
               $CellContext`parabola[$CellContext`x], {$CellContext`x, -30, 
                50}, PlotRange -> {-20, 50}, AspectRatio -> Automatic, 
               PlotLabel -> $CellContext`parabola[$CellContext`x]], 
              Graphics[$CellContext`rawgraphics], ImageSize -> 350]}, 
            Alignment -> Center]]]}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.481626237575327*^9, 3.481626267815627*^9, 
  3.4816268887948303`*^9}]
}, Open  ]],

Cell["Finding the parabola through entered points:", "Text",
 CellChangeTimes->{{3.481626799620451*^9, 3.481626826492855*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Example421", "[", 
    RowBox[{"pt1", ",", "pt2", ",", "pt3"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pt1", ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "21"}], ",", "17"}], "}"}], ",", " ", 
       "\"\<Point P\>\""}], "}"}], ",", " ", 
     RowBox[{"ControlType", "\[Rule]", "InputField"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pt2", ",", " ", 
       RowBox[{"{", 
        RowBox[{"9", ",", 
         RowBox[{"-", "6"}]}], "}"}], ",", " ", "\"\<Point Q\>\""}], "}"}], 
     ",", " ", 
     RowBox[{"ControlType", "\[Rule]", "InputField"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pt3", ",", " ", 
       RowBox[{"{", 
        RowBox[{"37", ",", "28"}], "}"}], ",", " ", "\"\<Point R\>\""}], 
      "}"}], ",", " ", 
     RowBox[{"ControlType", "\[Rule]", "InputField"}]}], "}"}], ",", " ", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.481626638828925*^9, 3.48162673923141*^9}, {
  3.4816268623810368`*^9, 3.481626866689741*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`pt1$$ = {-21, 17}, $CellContext`pt2$$ = {
    9, -6}, $CellContext`pt3$$ = {37, 28}, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`pt1$$], {-21, 17}, "Point P"}}, {{
       Hold[$CellContext`pt2$$], {9, -6}, "Point Q"}}, {{
       Hold[$CellContext`pt3$$], {37, 28}, "Point R"}}}, Typeset`size$$ = {
    438., {216.21875, 222.78125}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`pt1$$ = {-21, 17}, $CellContext`pt2$$ = {
         9, -6}, $CellContext`pt3$$ = {37, 28}}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`Example421[$CellContext`pt1$$, \
$CellContext`pt2$$, $CellContext`pt3$$], 
      "Specifications" :> {{{$CellContext`pt1$$, {-21, 17}, "Point P"}, 
         ControlType -> 
         InputField}, {{$CellContext`pt2$$, {9, -6}, "Point Q"}, ControlType -> 
         InputField}, {{$CellContext`pt3$$, {37, 28}, "Point R"}, ControlType -> 
         InputField}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{491., {299.21875, 305.78125}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`Example421[
         Pattern[$CellContext`pt1, 
          Blank[]], 
         Pattern[$CellContext`pt2, 
          Blank[]], 
         Pattern[$CellContext`pt3, 
          Blank[]]] := 
       Block[{$CellContext`parabola, $CellContext`rawgraphics, \
$CellContext`plot, $CellContext`ptlist, $CellContext`x}, If[Det[{
              Join[{1}, $CellContext`pt1], 
              Join[{1}, $CellContext`pt2], 
              Join[{1}, $CellContext`pt3]}] == 0, 
           Return[
            Plot[
            0, {$CellContext`x, -30, 50}, PlotRange -> {-20, 50}, AspectRatio -> 
             Automatic, PlotLabel -> 
             "There is no parabola fitting these points"]]]; \
$CellContext`parabola = 
          LinearModelFit[{$CellContext`pt1, $CellContext`pt2, \
$CellContext`pt3}, {
            1, $CellContext`x, $CellContext`x^2}, $CellContext`x]; \
$CellContext`rawgraphics = {
            Text["P", $CellContext`pt1, {0, 3}], 
            Text["Q", $CellContext`pt2, {0, 3}], 
            Text["R", $CellContext`pt3, {0, 3}], 
            PointSize[0.02], 
            
            Point[{$CellContext`pt1, $CellContext`pt2, $CellContext`pt3}]}; \
$CellContext`ptlist = {{
            "Point P", "Point Q", 
             "Point R"}, {{$CellContext`pt1}, {$CellContext`pt2}, \
{$CellContext`pt3}}}; Return[
           Column[{
             TableForm[$CellContext`ptlist], 
             Show[
              Plot[
               $CellContext`parabola[$CellContext`x], {$CellContext`x, -30, 
                50}, PlotRange -> {-20, 50}, AspectRatio -> Automatic, 
               PlotLabel -> $CellContext`parabola[$CellContext`x]], 
              Graphics[$CellContext`rawgraphics], ImageSize -> 350]}, 
            Alignment -> Center]]]}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.4816267416858597`*^9, 3.481626868200687*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{640, 750},
WindowMargins->{{274, Automatic}, {153, Automatic}},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 98, 1, 57, "Subtitle"],
Cell[668, 25, 795, 12, 164, "Text"],
Cell[1466, 39, 4577, 115, 23, "Input",
 CellOpen->False],
Cell[6046, 156, 126, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[6197, 161, 1150, 35, 23, "Input",
 CellOpen->False],
Cell[7350, 198, 3918, 82, 537, "Output"]
}, Open  ]],
Cell[11283, 283, 126, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[11434, 288, 1268, 36, 23, "Input",
 CellOpen->False],
Cell[12705, 326, 3835, 80, 625, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
