(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     10698,        295]
NotebookOptionsPosition[     10168,        271]
NotebookOutlinePosition[     10529,        287]
CellTagsIndexPosition[     10486,        284]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Example 6.1.2", "Subtitle",
 CellChangeTimes->{{3.481904344880021*^9, 3.481904347254346*^9}}],

Cell[TextData[{
 "This notebook shows a geometric interpretation of vector addition given in \
example 6.1.2.  Given vectors ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["v", "\[RightVector]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["w", "\[RightVector]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " in \"tail-to-tail\" position, the vector ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["v", "\[RightVector]"], "+", 
    OverscriptBox["w", "\[RightVector]"]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " is the diagonal of the parallelogram spanned by  ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["v", "\[RightVector]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["w", "\[RightVector]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " (that is, with ",
 " ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["v", "\[RightVector]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["w", "\[RightVector]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " as two of its sides)."
}], "Text",
 CellChangeTimes->{{3.4819043503681383`*^9, 3.4819045237487307`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ShowArrows", "[", " ", 
   RowBox[{"pt1_", ",", " ", "pt2_"}], "]"}], ":=", 
  RowBox[{"Block", "[", " ", 
   RowBox[{
    RowBox[{"{", "graphics", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"graphics", "=", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Blue", ",", " ", 
         RowBox[{"Arrow", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", "pt1"}], "}"}], "]"}], ",", 
         " ", "Red", ",", " ", 
         RowBox[{"Arrow", "[", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", "pt2"}], "}"}], "]"}], ",", 
         "Green", ",", " ", 
         RowBox[{"Arrow", "[", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", " ", 
            RowBox[{"pt1", "+", "pt2"}]}], "}"}], "]"}], ",", " ", "Black", 
         ",", " ", 
         RowBox[{"Text", "[", 
          RowBox[{"\"\<v\>\"", ",", 
           RowBox[{"pt1", "/", "2"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "1"}], "}"}]}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"\"\<w\>\"", ",", " ", 
           RowBox[{"pt2", "/", "2"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "1"}], "}"}]}], "]"}], ",", " ", 
         RowBox[{"Text", "[", 
          RowBox[{"\"\<v+w\>\"", ",", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"pt1", "+", "pt2"}], ")"}], "/", "2"}]}], "]"}], ",", 
         RowBox[{"Opacity", "[", ".1", "]"}], ",", " ", "Red", ",", " ", 
         RowBox[{"Polygon", "[", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", " ", "pt1", ",", " ", 
            RowBox[{"pt1", "+", "pt2"}], ",", "pt2"}], "}"}], "]"}]}], "}"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Return", "[", " ", 
      RowBox[{"Show", "[", 
       RowBox[{"graphics", ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "}"}]}], ",", " ", 
        RowBox[{"AxesOrigin", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], ",", " ", 
        RowBox[{"Axes", "\[Rule]", "True"}]}], "]"}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}], " "}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.4819035880670853`*^9, 3.481903589701592*^9}, {
  3.4819036290796747`*^9, 3.481903643510633*^9}, {3.481903700769114*^9, 
  3.481903885102426*^9}, {3.481903923491582*^9, 3.481904008314021*^9}, {
  3.481904041160019*^9, 3.481904057675537*^9}, {3.48190408870931*^9, 
  3.481904176117181*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"ShowArrows", "[", 
    RowBox[{"pt1", ",", "pt2"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pt1", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}], ",", "Locator", ",", 
     " ", 
     RowBox[{"Appearance", "\[Rule]", "None"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pt2", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}]}], "}"}], ",", "Locator", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "None"}]}], "}"}], ",", " ", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.481904010407216*^9, 3.481904015891398*^9}, {
  3.4819040695420628`*^9, 3.4819040740602283`*^9}, {3.48190418830338*^9, 
  3.481904252690534*^9}, {3.4819042986263943`*^9, 3.481904309818521*^9}, {
  3.481904861073381*^9, 3.481904867007887*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`pt1$$ = {-2, 2}, $CellContext`pt2$$ = {3, 
    1}, Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`pt1$$], {-2, 2}}, Automatic}, {{
       Hold[$CellContext`pt2$$], {3, 1}}, Automatic}}, Typeset`size$$ = {
    434., {214., 220.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`pt1$$ = {-2, 2}, $CellContext`pt2$$ = {3, 
         1}}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`ShowArrows[$CellContext`pt1$$, \
$CellContext`pt2$$], 
      "Specifications" :> {{{$CellContext`pt1$$, {-2, 2}}, Automatic, 
         ControlType -> Locator, Appearance -> 
         None}, {{$CellContext`pt2$$, {3, 1}}, Automatic, ControlType -> 
         Locator, Appearance -> None}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{495., {252.21875, 258.78125}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`ShowArrows[
         Pattern[$CellContext`pt1, 
          Blank[]], 
         Pattern[$CellContext`pt2, 
          Blank[]]] := 
       Block[{$CellContext`graphics}, $CellContext`graphics = 
          Graphics[{Blue, 
             Arrow[{{0, 0}, $CellContext`pt1}], Red, 
             Arrow[{{0, 0}, $CellContext`pt2}], Green, 
             Arrow[{{0, 0}, $CellContext`pt1 + $CellContext`pt2}], Black, 
             Text["v", $CellContext`pt1/2, {1, 1}], 
             Text["w", $CellContext`pt2/2, {1, 1}], 
             Text["v+w", ($CellContext`pt1 + $CellContext`pt2)/2], 
             Opacity[0.1], Red, 
             
             Polygon[{{0, 
               0}, $CellContext`pt1, $CellContext`pt1 + $CellContext`pt2, \
$CellContext`pt2}]}]; Return[
           
           Show[$CellContext`graphics, PlotRange -> {{-5, 5}, {-5, 5}}, 
            AxesOrigin -> {0, 0}, Axes -> True]]], $CellContext`ShowArrows[
         Pattern[$CellContext`pt1, 
          Blank[]], 
         Pattern[$CellContext`pt2, 
          Blank[]], 
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]]] := 
       Block[{$CellContext`graphics}, $CellContext`graphics = Graphics[{
             Opacity[0.3], Blue, 
             Arrow[{{0, 0}, $CellContext`pt1}], Red, 
             Arrow[{{0, 0}, $CellContext`pt2}], Green, 
             Opacity[1], 
             
             Arrow[{{0, 
               0}, $CellContext`a $CellContext`pt1 + $CellContext`b \
$CellContext`pt2}], Blue, 
             Arrow[{{0, 0}, $CellContext`a $CellContext`pt1}], Red, 
             Arrow[{{0, 0}, $CellContext`b $CellContext`pt2}], Black, 
             Text["v", $CellContext`pt1/2, {1, 1}], 
             Text["w", $CellContext`pt2/2, {1, 1}], 
             Text[
             "a*v+b*w", ($CellContext`a $CellContext`pt1 + $CellContext`b \
$CellContext`pt2)/2], 
             
             Line[{$CellContext`a $CellContext`pt1, $CellContext`a \
$CellContext`pt1 + $CellContext`b $CellContext`pt2, $CellContext`b \
$CellContext`pt2}]}]; Return[
           
           Show[$CellContext`graphics, PlotRange -> {{-5, 5}, {-5, 5}}, 
            AxesOrigin -> {0, 0}, Axes -> True]]]}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.481904246728819*^9, 3.481904253281784*^9}, {
   3.481904299578754*^9, 3.4819043108338413`*^9}, 3.481904868154183*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{640, 750},
WindowMargins->{{36, Automatic}, {Automatic, 84}},
ShowSelection->True,
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 99, 1, 57, "Subtitle"],
Cell[669, 25, 1297, 42, 74, "Text"],
Cell[1969, 69, 2984, 76, 23, "Input",
 CellOpen->False],
Cell[CellGroupData[{
Cell[4978, 149, 995, 26, 23, "Input",
 CellOpen->False],
Cell[5976, 177, 4164, 90, 531, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
