(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     11614,        309]
NotebookOptionsPosition[     11105,        286]
NotebookOutlinePosition[     11443,        301]
CellTagsIndexPosition[     11400,        298]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Example 6.4.1", "Subtitle",
 CellChangeTimes->{{3.481904344880021*^9, 3.481904347254346*^9}, {
  3.4918330689442*^9, 3.491833069757598*^9}}],

Cell[TextData[{
 "This notebook shows the geometric interpretation of vector projection given \
in example 6.4.1.  Given vectors ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["v", "\[RightVector]"], TraditionalForm]]],
 " (in blue) and ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["w", "\[RightVector]"], TraditionalForm]]],
 " (in green),  the projection of ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["w", "\[RightVector]"], TraditionalForm]]],
 " onto ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["v", "\[RightVector]"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["proj", 
     OverscriptBox["v", "\[RightVector]"]], "(", 
    OverscriptBox["w", "\[RightVector]"], ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", is given in red. The vectors ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["w", "\[RightVector]"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["v", "\[RightVector]"], TraditionalForm]]],
 " may be changed by dragging their endpoint.  Also shown in gray is the \
vector ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["w", "\[RightVector]"], "-", 
    RowBox[{
     SubscriptBox["proj", 
      OverscriptBox["v", "\[RightVector]"]], "(", 
     OverscriptBox["w", "\[RightVector]"], ")"}]}], TraditionalForm]]],
 ", which is always orthogonal to ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["v", "\[RightVector]"], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.4819043503681383`*^9, 3.4819045237487307`*^9}, {
   3.491833079665924*^9, 3.491833272259077*^9}, 3.4918335012112837`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DisplayProjectedVector", "[", 
    RowBox[{"w_", ",", "v_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "graphics", ",", " ", "proj", ",", " ", "perpendicular", ",", "k"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"proj", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"w", ".", "v"}], "/", 
         RowBox[{"v", ".", "v"}]}], " ", "v"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"perpendicular", "=", 
       RowBox[{"w", "-", "proj"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"graphics", "=", 
       RowBox[{"Graphics", "[", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Blue", ",", " ", 
          RowBox[{"Arrow", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], ",", "v"}], "}"}], "]"}], ",", 
          " ", "Green", ",", 
          RowBox[{"Arrow", "[", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], ",", " ", "w"}], "}"}], "]"}], 
          ",", " ", "Red", ",", 
          RowBox[{"Arrow", "[", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], ",", "proj"}], "}"}], "]"}], 
          ",", " ", "Gray", ",", " ", 
          RowBox[{"Arrow", "[", " ", 
           RowBox[{"{", 
            RowBox[{"proj", ",", " ", "w"}], "}"}], "]"}], ",", " ", "Black", 
          ",", 
          RowBox[{"Text", "[", " ", 
           RowBox[{"\"\<w\>\"", ",", " ", 
            RowBox[{"w", "+", 
             RowBox[{"{", 
              RowBox[{".25", ",", ".25"}], "}"}]}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{"\"\<v\>\"", ",", " ", 
            RowBox[{"v", "+", 
             RowBox[{"{", 
              RowBox[{".25", ",", ".25"}], "}"}]}]}], "]"}]}], "}"}], "]"}]}],
       ";", "\[IndentingNewLine]", 
      RowBox[{"Return", "[", " ", 
       RowBox[{"Column", "[", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Show", "[", 
           RowBox[{"graphics", ",", " ", 
            RowBox[{"PlotRange", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "5"}], "}"}]}], "}"}]}], ",", " ", 
            RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", " ", 
            RowBox[{"Axes", "\[Rule]", "True"}], ",", " ", 
            RowBox[{"Ticks", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Table", "[", 
                RowBox[{"k", ",", 
                 RowBox[{"{", 
                  RowBox[{"k", ",", 
                   RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "]"}], ",", 
               RowBox[{"Table", "[", 
                RowBox[{"k", ",", 
                 RowBox[{"{", 
                  RowBox[{"k", ",", 
                   RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "]"}]}], "}"}]}], 
            ",", " ", 
            RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Row", "[", " ", 
           RowBox[{"{", 
            RowBox[{
            "\"\<The vector projection of the green vector w \>\"", ",", " ", 
             "w", ",", " ", "\"\< onto the blue vector v \>\"", ",", "v", 
             ",", "\"\< is the red vector \>\"", ",", " ", "proj"}], "}"}], 
           "]"}]}], "}"}], "]"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.491765150770896*^9, 3.4917655919748487`*^9}, {
  3.491765624816163*^9, 3.4917656952209787`*^9}, {3.491765790664706*^9, 
  3.491765900767317*^9}, {3.4917659497687283`*^9, 3.491766002946178*^9}, {
  3.491766036965293*^9, 3.4917661287606792`*^9}, {3.4917721273512297`*^9, 
  3.491772180054105*^9}, {3.491832903571306*^9, 3.491832928393976*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"DisplayProjectedVector", "[", 
    RowBox[{"w1", ",", "v1"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"v1", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "0"}], "}"}]}], "}"}], ",", "Locator", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "None"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"w1", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3"}], "}"}]}], "}"}], ",", "Locator", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "None"}]}], "}"}], ",", " ", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.491765708077482*^9, 3.491765717871221*^9}, {
  3.491765759131516*^9, 3.491765776356092*^9}, {3.491766145702423*^9, 
  3.491766184618848*^9}, {3.491772197951936*^9, 3.491772215184126*^9}, {
  3.491832981049823*^9, 3.49183299315803*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`v1$$ = {3, 0}, $CellContext`w1$$ = {2, 3}, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`v1$$], {3, 0}}, Automatic}, {{
       Hold[$CellContext`w1$$], {2, 3}}, Automatic}}, Typeset`size$$ = {
    678., {150.21875, 156.78125}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`v1$$ = {3, 0}, $CellContext`w1$$ = {2, 3}},
       "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`DisplayProjectedVector[$CellContext`w1$$, \
$CellContext`v1$$], 
      "Specifications" :> {{{$CellContext`v1$$, {3, 0}}, Automatic, 
         ControlType -> Locator, Appearance -> 
         None}, {{$CellContext`w1$$, {2, 3}}, Automatic, ControlType -> 
         Locator, Appearance -> None}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{739., {189.21875, 195.78125}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`DisplayProjectedVector[
         Pattern[$CellContext`w, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := 
       Block[{$CellContext`graphics, $CellContext`proj, \
$CellContext`perpendicular, $CellContext`k}, $CellContext`proj = (
            Dot[$CellContext`w, $CellContext`v]/
            Dot[$CellContext`v, $CellContext`v]) $CellContext`v; \
$CellContext`perpendicular = $CellContext`w - $CellContext`proj; \
$CellContext`graphics = Graphics[{Thick, Blue, 
             Arrow[{{0, 0}, $CellContext`v}], Green, 
             Arrow[{{0, 0}, $CellContext`w}], Red, 
             Arrow[{{0, 0}, $CellContext`proj}], Gray, 
             Arrow[{$CellContext`proj, $CellContext`w}], Black, 
             Text["w", $CellContext`w + {0.25, 0.25}], 
             Text["v", $CellContext`v + {0.25, 0.25}]}]; Return[
           Column[{
             
             Show[$CellContext`graphics, PlotRange -> {{-5, 5}, {0, 5}}, 
              AspectRatio -> Automatic, Axes -> True, Ticks -> {
                Table[$CellContext`k, {$CellContext`k, -5, 5}], 
                Table[$CellContext`k, {$CellContext`k, -5, 5}]}, ImageSize -> 
              400], 
             
             Row[{"The vector projection of the green vector w ", \
$CellContext`w, " onto the blue vector v ", $CellContext`v, 
               " is the red vector ", $CellContext`proj}]}]]]}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.4917657185169277`*^9, {3.491765759462776*^9, 3.49176577691964*^9}, {
   3.491765817618514*^9, 3.491765833269957*^9}, {3.491765882897355*^9, 
   3.491765902661375*^9}, {3.491765990513062*^9, 3.491766006932671*^9}, {
   3.491766039572173*^9, 3.4917661317880497`*^9}, 3.49176618818359*^9, 
   3.491772167484502*^9, {3.491772198969574*^9, 3.4917722157574787`*^9}, {
   3.491832993964265*^9, 3.491833015436002*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{884, 821},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 146, 2, 57, "Subtitle"],
Cell[716, 26, 1609, 51, 84, "Text"],
Cell[2328, 79, 4107, 101, 23, "Input",
 CellOpen->False],
Cell[CellGroupData[{
Cell[6460, 184, 966, 24, 23, "Input",
 CellOpen->False],
Cell[7429, 210, 3648, 72, 405, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
