(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     18589,        466]
NotebookOptionsPosition[     18075,        443]
NotebookOutlinePosition[     18413,        458]
CellTagsIndexPosition[     18370,        455]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Example 6.4.5", "Subtitle",
 CellChangeTimes->{{3.492100056316592*^9, 3.4921000590134563`*^9}}],

Cell["\<\
This notebook illustrates the notion of the distance from a point to the \
plane discussed in example 6.4.5 of the textbook.  You enter the equation of \
a non-vertical plane by giving its left-hand side (where we place all the \
variables) and its right-hand side (which must be a number).  You also give \
the coordinates of the point whose distance to the plane needs to be found.

The manipulation then graphs the plane, the point you gave, and a number of \
other quantites.  First, it creates the normal line to the plane in green. It \
then creates a red point in the plane that you may move around via a \
2-dimensional slider.  From this point it makes the vector from the red \
\"point in plane\" to the black point you entered, and forms the projection \
of this red vector onto the normal line (the projection itself is blue, and \
to aid with perspective the projection itself is shaded).  The length of this \
blue projection is the distance from the point to the plane.  Note that the \
blue projection (which represents the distance) never changes as the red \
point slides around in the plane.\
\>", "Text",
 CellChangeTimes->{{3.492100065468873*^9, 3.492100454076385*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PointtoPlane", "[", " ", 
    RowBox[{
    "lhs_", ",", " ", "rhs_", ",", " ", "ptinspace_", ",", " ", "param1_", 
     ",", "param2_", ",", 
     RowBox[{"{", 
      RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}]}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"Block", "[", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "normal", ",", " ", "distance", ",", " ", "planeplot", ",", " ", 
       "graphics", ",", "movingpoint", ",", " ", "closestpoint", ",", "t", 
       ",", "max", ",", "min"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"normal", "=", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Coefficient", "[", 
          RowBox[{"lhs", ",", "x"}], "]"}], ",", 
         RowBox[{"Coefficient", "[", 
          RowBox[{"lhs", ",", "y"}], "]"}], ",", 
         RowBox[{"Coefficient", "[", 
          RowBox[{"lhs", ",", "z"}], "]"}]}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"normal", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "\[Equal]", "0"}], ",", " ", 
        RowBox[{
         RowBox[{
         "Print", "[", 
          "\"\<This manipulation assumes the place is not vertical.\>\"", 
          "]"}], ";", " ", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"distance", "=", 
       RowBox[{
        RowBox[{"Abs", "[", " ", 
         RowBox[{
          RowBox[{"normal", ".", "ptinspace"}], "-", "rhs"}], "]"}], "/", 
        RowBox[{"Norm", "[", "normal", "]"}]}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"closestpoint", "=", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", "y", ",", "z"}], "}"}], "/.", 
        RowBox[{
         RowBox[{"Solve", "[", " ", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{"x", ",", "y", ",", "z"}], "}"}], "\[Equal]", 
              RowBox[{"ptinspace", "+", 
               RowBox[{"t", " ", "normal"}]}]}], ",", " ", 
             RowBox[{"lhs", "\[Equal]", "rhs"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "y", ",", "z", ",", "t"}], "}"}]}], "]"}], "[", 
         
         RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"max", "=", 
       RowBox[{
        RowBox[{"NMaximize", "[", " ", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"rhs", "-", 
               RowBox[{
                RowBox[{"normal", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], "x"}], "-", 
               RowBox[{
                RowBox[{"normal", "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "y"}]}], ")"}], "/", 
             RowBox[{"normal", "[", 
              RowBox[{"[", "3", "]"}], "]"}]}], ",", " ", 
            RowBox[{
             RowBox[{
              RowBox[{"closestpoint", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "-", 
              RowBox[{"2", "distance"}]}], "\[LessEqual]", " ", "x", 
             "\[LessEqual]", " ", 
             RowBox[{
              RowBox[{"closestpoint", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "+", 
              RowBox[{"2", "distance"}]}]}], ",", " ", 
            RowBox[{
             RowBox[{
              RowBox[{"closestpoint", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "-", 
              RowBox[{"2", "distance"}]}], "\[LessEqual]", " ", "y", 
             "\[LessEqual]", " ", 
             RowBox[{
              RowBox[{"closestpoint", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "+", 
              RowBox[{"2", "distance"}]}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "y"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"min", "=", 
       RowBox[{
        RowBox[{"NMinimize", "[", " ", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"rhs", "-", 
               RowBox[{
                RowBox[{"normal", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], "x"}], "-", 
               RowBox[{
                RowBox[{"normal", "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "y"}]}], ")"}], "/", 
             RowBox[{"normal", "[", 
              RowBox[{"[", "3", "]"}], "]"}]}], ",", " ", 
            RowBox[{
             RowBox[{
              RowBox[{"closestpoint", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "-", 
              RowBox[{"2", "distance"}]}], "\[LessEqual]", " ", "x", 
             "\[LessEqual]", " ", 
             RowBox[{
              RowBox[{"closestpoint", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "+", 
              RowBox[{"2", "distance"}]}]}], ",", " ", 
            RowBox[{
             RowBox[{
              RowBox[{"closestpoint", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "-", 
              RowBox[{"2", "distance"}]}], "\[LessEqual]", " ", "y", 
             "\[LessEqual]", " ", 
             RowBox[{
              RowBox[{"closestpoint", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "+", 
              RowBox[{"2", "distance"}]}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "y"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"movingpoint", "=", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"closestpoint", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{"closestpoint", "[", 
           RowBox[{"[", "2", "]"}], "]"}], ",", "0"}], "}"}], "+", " ", 
        RowBox[{"{", " ", 
         RowBox[{
          RowBox[{"2", "param1", " ", "distance"}], ",", "  ", 
          RowBox[{"2", "param2", " ", "distance"}], ",", " ", 
          RowBox[{"z", "/.", " ", 
           RowBox[{
            RowBox[{"Solve", "[", " ", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"lhs", "\[Equal]", "rhs"}], ",", " ", 
                RowBox[{"x", "\[Equal]", 
                 RowBox[{
                  RowBox[{"closestpoint", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "+", " ", 
                  RowBox[{"2", "param1", " ", "distance"}]}]}], ",", " ", 
                RowBox[{"y", "\[Equal]", " ", 
                 RowBox[{
                  RowBox[{"2", "param2", " ", "distance"}], "+", 
                  RowBox[{"closestpoint", "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}]}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"planeplot", "=", 
       RowBox[{"ContourPlot3D", "[", 
        RowBox[{
         RowBox[{"lhs", "\[Equal]", "rhs"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{
            RowBox[{"closestpoint", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "-", "distance"}], ",", " ", 
           RowBox[{
            RowBox[{"closestpoint", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "+", "distance"}]}], "}"}], ",", 
         
         RowBox[{"{", 
          RowBox[{"y", ",", 
           RowBox[{
            RowBox[{"closestpoint", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "-", "distance"}], ",", " ", 
           RowBox[{
            RowBox[{"closestpoint", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "+", "distance"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"z", ",", "min", ",", "max"}], "}"}], ",", " ", 
         RowBox[{"Mesh", "\[Rule]", "None"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"graphics", "=", 
       RowBox[{"{", 
        RowBox[{"Green", ",", " ", 
         RowBox[{"Arrow", "[", 
          RowBox[{"{", 
           RowBox[{"closestpoint", ",", 
            RowBox[{"ptinspace", "+", 
             RowBox[{
              RowBox[{"normal", "/", 
               RowBox[{"Norm", "[", "normal", "]"}]}], " ", "distance"}]}]}], 
           "}"}], "]"}], ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{"closestpoint", ",", 
            RowBox[{"closestpoint", "-", 
             RowBox[{
              RowBox[{"normal", "/", 
               RowBox[{"Norm", "[", "normal", "]"}]}], " ", "distance"}]}]}], 
           "}"}], "]"}], ",", 
         RowBox[{"PointSize", "[", ".035", "]"}], ",", "Blue", ",", " ", 
         RowBox[{"Point", "[", "closestpoint", "]"}], ",", " ", 
         RowBox[{"Arrow", "[", " ", 
          RowBox[{"{", 
           RowBox[{"closestpoint", ",", "ptinspace"}], "}"}], "]"}], ",", " ",
          "Red", ",", " ", 
         RowBox[{"Point", "[", " ", "movingpoint", "]"}], ",", " ", "Black", 
         ",", " ", 
         RowBox[{"Point", "[", "ptinspace", "]"}], ",", " ", "Red", ",", " ", 
         
         RowBox[{"Arrow", "[", " ", 
          RowBox[{"{", 
           RowBox[{"movingpoint", ",", "ptinspace"}], "}"}], "]"}], ",", " ", 
         
         RowBox[{"Opacity", "[", ".3", "]"}], ",", " ", 
         RowBox[{"Polygon", "[", " ", 
          RowBox[{"{", 
           RowBox[{
           "movingpoint", ",", " ", "closestpoint", ",", " ", "ptinspace"}], 
           "}"}], "]"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Column", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Row", "[", 
          RowBox[{"{", 
           RowBox[{
           "\"\<The normal line intersects the plane at the blue point \>\"", 
            ",", "closestpoint"}], "}"}], "]"}], ",", 
         RowBox[{"Row", "[", 
          RowBox[{"{", 
           RowBox[{
           "\"\<The distance from the black point to the blue point (i.e. \
distance to the plane) is \>\"", ",", "distance"}], "}"}], "]"}], ",", 
         RowBox[{"Row", "[", 
          RowBox[{"{", 
           RowBox[{
           "\"\<The current red point is \>\"", ",", " ", "movingpoint"}], 
           "}"}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"Graphics3D", "[", "graphics", "]"}], ",", "planeplot", 
           ",", " ", 
           RowBox[{"Axes", "\[Rule]", "True"}], ",", " ", 
           RowBox[{"AxesLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\""}], 
             "}"}]}]}], "]"}]}], "}"}], "]"}]}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "Input",
 CellOpen->False,
 CellChangeTimes->CompressedData["
1:eJwdzUsowwEAx/G/IWWybBevpYmsHbyyLGHtMNG8KayGiaaVeUatndDKYofR
ZvI6bPNIwkEkxYxmSzaTJFscSCvG2K6z3//w63P51ZfVM9jcRyEIIis6qBsP
S0xxfoHjYKobHqcK+yGfsJAm5EoHoJ6hG4NcY56K/D/Z12Dlbuc2ZLto+/Cg
bvIcZgYWSF2c4CVUzn06oHDM44bFr6FfmOg945ij+oQ/BTBnOVIOJXovHy6F
khvhjOKtCd6PZnRAHudPDinM3iEY20AbhkpbzASklp7qYNXVtAFak+xGuLey
sw5lNtYGdNJbrNA1wrNDbSb7BnbZ3G4o15x4Yfat6AWqI9JvWJ2rCkN67TfF
EvWrsD4W0sPZVHjnTc+HygxGCTQE2RVQlM8VwPa2lBqo6ZHVQ2L8mVQdr2mF
D+4LMVTo0+ZhWZNnFX74TZtw9tq8BR8DRXtkZ/HiEE6Ij5xQ2+t7hxZm8xe0
CVg/8B9OEO5f
  "]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"PointtoPlane", "[", 
    RowBox[{"planelhs", ",", "planerhs", ",", "thepoint", ",", 
     RowBox[{"param", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{"param", "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"planelhs", ",", 
      RowBox[{
       RowBox[{"2", "x"}], "-", 
       RowBox[{"3", "y"}], "+", 
       RowBox[{"6", "z"}]}], ",", "\"\<Plane left-hand side \>\""}], "}"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"planerhs", ",", "1", ",", "\"\<Plane right-hand side\>\""}], 
     "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"thepoint", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "7"}], "}"}], ",", "\"\<The point\>\""}], 
     "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"param", ",", 
       RowBox[{"{", 
        RowBox[{".25", ",", ".25"}], "}"}], ",", 
       "\"\<point in plane location\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", ".5"}], ",", 
       RowBox[{"-", ".5"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{".5", ",", ".5"}], "}"}]}], "}"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.492095231963174*^9, 3.492095253765888*^9}, {
   3.492096535755952*^9, 3.492096543338077*^9}, {3.492096585940136*^9, 
   3.4920965874902*^9}, {3.492096663004548*^9, 3.492096689796445*^9}, {
   3.4920971858066473`*^9, 3.4920972070524673`*^9}, 3.492097263198497*^9, {
   3.492097299414469*^9, 3.4920973008686237`*^9}, {3.492097420207148*^9, 
   3.492097504511115*^9}, {3.492097995914482*^9, 3.492098005560755*^9}, {
   3.492098812670402*^9, 3.492098968710786*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`param$$ = {0.25, 
    0.25}, $CellContext`planelhs$$ = 2 $CellContext`x - 3 $CellContext`y + 
    6 $CellContext`z, $CellContext`planerhs$$ = 1, $CellContext`thepoint$$ = {
    1, 1, 7}, Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`planelhs$$], 2 $CellContext`x - 3 $CellContext`y + 
       6 $CellContext`z, "Plane left-hand side "}}, {{
       Hold[$CellContext`planerhs$$], 1, "Plane right-hand side"}}, {{
       Hold[$CellContext`thepoint$$], {1, 1, 7}, "The point"}}, {{
       Hold[$CellContext`param$$], {0.25, 0.25}, 
       "point in plane location"}, {-0.5, -0.5}, {0.5, 0.5}}}, 
    Typeset`size$$ = {635., {303.71875, 310.28125}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`param$32475$$ = {0, 0}}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`param$$ = {0.25, 
         0.25}, $CellContext`planelhs$$ = 
        2 $CellContext`x - 3 $CellContext`y + 
         6 $CellContext`z, $CellContext`planerhs$$ = 
        1, $CellContext`thepoint$$ = {1, 1, 7}}, "ControllerVariables" :> {
        Hold[$CellContext`param$$, $CellContext`param$32475$$, {0, 0}]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`PointtoPlane[$CellContext`planelhs$$, \
$CellContext`planerhs$$, $CellContext`thepoint$$, 
        Part[$CellContext`param$$, 1], 
        Part[$CellContext`param$$, 
         2], {$CellContext`x, $CellContext`y, $CellContext`z}], 
      "Specifications" :> {{{$CellContext`planelhs$$, 2 $CellContext`x - 
          3 $CellContext`y + 6 $CellContext`z, 
          "Plane left-hand side "}}, {{$CellContext`planerhs$$, 1, 
          "Plane right-hand side"}}, {{$CellContext`thepoint$$, {1, 1, 7}, 
          "The point"}}, {{$CellContext`param$$, {0.25, 0.25}, 
          "point in plane location"}, {-0.5, -0.5}, {0.5, 0.5}}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{688., {440.21875, 446.78125}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.492098918771627*^9, 3.49209896950988*^9, 3.492099049289152*^9, {
   3.4920993056246033`*^9, 3.492099320086355*^9}, 3.4920994285823298`*^9, 
   3.4921000792558002`*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{834, 889},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 101, 1, 57, "Subtitle"],
Cell[671, 25, 1200, 18, 239, "Text"],
Cell[1874, 45, 11330, 283, 23, "Input",
 CellOpen->False],
Cell[CellGroupData[{
Cell[13229, 332, 1848, 49, 23, "Input",
 CellOpen->False],
Cell[15080, 383, 2967, 56, 907, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
