(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     20250,        489]
NotebookOptionsPosition[     19737,        466]
NotebookOutlinePosition[     20075,        481]
CellTagsIndexPosition[     20032,        478]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Example 7.2.2", "Subtitle",
 CellChangeTimes->{{3.492258636882883*^9, 3.492258652209585*^9}}],

Cell[TextData[{
 "This notebook generalizes the display of curvature and osculating circle \
for a two-dimensional curve as given in example 7.2.2 of the text.  Simply \
enter a parametric curve, the starting and ending values for the parameter ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", ",
 Cell[BoxData[
  FormBox[Cell[""], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "and you will get 2 different graphs.  One is the graph of the curve itself, \
together with the osculating circle at a point (the point on the curve is \
controlled by the slider).  The second graph graphs only the value of the \
curvature and indicates where on the graph the current point in the curve is. \
 Remember, since the radius of the osculating circle is the reciprocal of the \
curvature, larger curvature values should lead to smaller circles.\n\nNote:  \
You must use ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " as the parameter here, so make sure you haven't defined ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " to be a specific number."
}], "Text",
 CellChangeTimes->{{3.492258659587001*^9, 3.4922589402130327`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"OsculatingCirclein2D", "[", " ", 
     RowBox[{"curve_", ",", " ", 
      RowBox[{"{", 
       RowBox[{"t_", ",", "a_", ",", "b_"}], "}"}], ",", "t0_"}], "]"}], ":=",
     "\[IndentingNewLine]", 
    RowBox[{"Block", "[", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "curvature", ",", " ", "radius", ",", "center", ",", "graphics", ",", 
        "k", ",", "x", ",", "y", ",", "xmin", ",", "xmax", ",", "ymin", ",", 
        "ymax", ",", "pts", ",", "r", ",", "normal", ",", " ", "n", ",", 
        "tangent", ",", "ptoncurve", ",", "maxcurvature"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"x", "=", 
        RowBox[{"curve", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", 
       RowBox[{"y", "=", 
        RowBox[{"curve", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"curvature", "=", 
        RowBox[{
         RowBox[{"Abs", "[", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{"x", ",", "t"}], "]"}], 
            RowBox[{"D", "[", 
             RowBox[{"y", ",", "t", ",", "t"}], "]"}]}], "-", 
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{"y", ",", "t"}], "]"}], 
            RowBox[{"D", "[", 
             RowBox[{"x", ",", "t", ",", "t"}], "]"}]}]}], "]"}], "/", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"D", "[", 
              RowBox[{"x", ",", "t"}], "]"}], "^", "2"}], "+", 
            RowBox[{
             RowBox[{"D", "[", 
              RowBox[{"y", ",", "t"}], "]"}], "^", "2"}]}], ")"}], "^", 
          RowBox[{"(", 
           RowBox[{"3", "/", "2"}], ")"}]}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tangent", "=", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"curve", ",", "t"}], "]"}], "/", 
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{"curve", ",", "t"}], "]"}], ".", 
           RowBox[{"D", "[", 
            RowBox[{"curve", ",", "t"}], "]"}]}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"normal", "=", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"tangent", ",", "t"}], "]"}], "/", 
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{"tangent", ",", "t"}], "]"}], ".", 
           RowBox[{"D", "[", 
            RowBox[{"tangent", ",", "t"}], "]"}]}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"radius", " ", "=", " ", 
        RowBox[{"1", "/", "curvature"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"pts", "=", 
        RowBox[{"Transpose", "[", 
         RowBox[{"Table", "[", " ", 
          RowBox[{"curve", ",", 
           RowBox[{"{", 
            RowBox[{"t", ",", "a", ",", "b", ",", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"b", "-", "a"}], ")"}], "/", "50"}]}], "}"}]}], "]"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xmin", ",", "xmax"}], "}"}], "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", 
            RowBox[{"pts", "[", 
             RowBox[{"[", "1", "]"}], "]"}], " ", "]"}], "-", ".5"}], ",", 
          " ", 
          RowBox[{
           RowBox[{"Max", "[", 
            RowBox[{"pts", "[", 
             RowBox[{"[", "1", "]"}], "]"}], " ", "]"}], "+", ".5"}]}], 
         "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"ymin", ",", "ymax"}], "}"}], "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", 
            RowBox[{"pts", "[", 
             RowBox[{"[", "2", "]"}], "]"}], " ", "]"}], "-", ".5"}], ",", 
          " ", 
          RowBox[{
           RowBox[{"Max", "[", " ", 
            RowBox[{"pts", "[", 
             RowBox[{"[", "2", "]"}], "]"}], " ", "]"}], "+", ".5"}]}], 
         "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"maxcurvature", "=", 
        RowBox[{
         RowBox[{"Max", "[", 
          RowBox[{"Table", "[", 
           RowBox[{"curvature", ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "a", ",", "b", ",", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"b", "-", "a"}], ")"}], "/", "50"}]}], "}"}]}], "]"}],
           "]"}], "+", ".5"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"r", "=", 
        RowBox[{"radius", " ", "/.", " ", 
         RowBox[{"t", "\[Rule]", " ", "t0"}]}]}], ";", "\[IndentingNewLine]", 
       
       RowBox[{"n", "=", 
        RowBox[{"normal", "/.", " ", 
         RowBox[{"t", "\[Rule]", "t0"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"k", "=", 
        RowBox[{"curvature", " ", "/.", " ", 
         RowBox[{"t", "\[Rule]", "t0"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"ptoncurve", "=", 
        RowBox[{"curve", "/.", " ", 
         RowBox[{"t", "\[Rule]", "t0"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"center", " ", "=", " ", 
        RowBox[{"ptoncurve", "+", 
         RowBox[{
          RowBox[{"1", "/", "k"}], " ", "n"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"graphics", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"PointSize", "[", ".03", "]"}], ",", " ", 
          RowBox[{"Point", "[", " ", "ptoncurve", "]"}], ",", " ", "Red", ",", 
          RowBox[{"Point", "[", " ", 
           RowBox[{"ptoncurve", "+", 
            RowBox[{
             RowBox[{"1", "/", "k"}], " ", "n"}]}], "]"}], ",", " ", 
          RowBox[{"Circle", "[", 
           RowBox[{"center", " ", ",", "r"}], "]"}], ",", " ", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{"ptoncurve", ",", "center"}], "}"}], "]"}]}], "}"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"Column", "[", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Show", "[", 
           RowBox[{
            RowBox[{"ParametricPlot", "[", 
             RowBox[{"curve", ",", 
              RowBox[{"{", 
               RowBox[{"t", ",", "a", ",", "b"}], "}"}], ",", 
              RowBox[{"PlotLabel", "->", 
               RowBox[{"StringJoin", "[", 
                RowBox[{"\"\<The current point is \>\"", ",", 
                 RowBox[{"ToString", "[", 
                  RowBox[{"Chop", "[", "ptoncurve", "]"}], "]"}]}], "]"}]}]}],
              "]"}], ",", " ", 
            RowBox[{"Graphics", "[", "graphics", "]"}], ",", " ", 
            RowBox[{"PlotRange", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"ymin", ",", "ymax"}], "}"}]}], "}"}]}], ",", 
            RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", " ", 
            RowBox[{"ImageSize", "\[Rule]", "275"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Show", "[", 
           RowBox[{
            RowBox[{"Plot", "[", 
             RowBox[{"curvature", ",", " ", 
              RowBox[{"{", 
               RowBox[{"t", ",", "a", ",", "b"}], "}"}], ",", " ", 
              RowBox[{"PlotLabel", "\[Rule]", " ", 
               RowBox[{"StringJoin", "[", 
                RowBox[{"\"\<The current curvature is \>\"", ",", " ", 
                 RowBox[{"ToString", "[", "k", "]"}]}], "]"}]}]}], "]"}], ",", 
            RowBox[{"Graphics", "[", 
             RowBox[{"{", 
              RowBox[{"Red", ",", 
               RowBox[{"Line", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"t0", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"t0", ",", "maxcurvature"}], "}"}]}], "}"}], 
                "]"}]}], "}"}], "]"}], " ", ",", 
            RowBox[{"ImageSize", "\[Rule]", "225"}]}], "  ", "]"}]}], "}"}], 
        "]"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.4922531254237423`*^9, 3.492253151712734*^9}, {
  3.492253236482436*^9, 3.4922532968104343`*^9}, {3.492253338428368*^9, 
  3.492253366408556*^9}, {3.492253398429062*^9, 3.492253469310482*^9}, {
  3.492253512126711*^9, 3.492254042963695*^9}, {3.492254082574161*^9, 
  3.492254298768023*^9}, {3.492254392989554*^9, 3.492254448448207*^9}, {
  3.492254499387558*^9, 3.49225455795296*^9}, {3.492254605014947*^9, 
  3.4922547557628107`*^9}, {3.492255059836472*^9, 3.49225509384319*^9}, {
  3.492255124794537*^9, 3.4922551288344307`*^9}, {3.492255164096154*^9, 
  3.4922551811298532`*^9}, {3.492255217221002*^9, 3.4922552391133738`*^9}, {
  3.492255275574936*^9, 3.492255320455703*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"OsculatingCirclein2D", "[", 
    RowBox[{"curve", ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "a", ",", "b"}], "}"}], ",", 
     RowBox[{"a", "+", 
      RowBox[{"u", 
       RowBox[{"(", 
        RowBox[{"b", "-", "a"}], ")"}]}]}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"curve", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"2", 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", ".2"}], "t"}], "]"}], 
         RowBox[{"Cos", "[", "t", "]"}]}], ",", 
        RowBox[{"2", 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", ".2"}], "t"}], "]"}], 
         RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}], ",", 
      "\"\<Curve formula\>\""}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"a", ",", "0", " ", ",", "\"\<Parameter start value\>\""}], 
     "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"b", ",", 
      RowBox[{"4", "Pi"}], ",", " ", "\"\<Parameter end value\>\""}], "}"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"u", ",", "0", ",", "\"\<Point slider\>\""}], "}"}], ",", "0", 
     ",", "1", ",", ".01"}], "}"}], ",", " ", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.492254309136394*^9, 3.49225437398022*^9}, 
   3.4922545818234367`*^9, {3.492254825847644*^9, 3.4922549625915527`*^9}, {
   3.4922550239064302`*^9, 3.4922550407624817`*^9}, {3.492258571617391*^9, 
   3.492258614343255*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0, $CellContext`b$$ = 4 
    Pi, $CellContext`curve$$ = {
    2 E^((-0.2) $CellContext`t) Cos[$CellContext`t], 2 
     E^((-0.2) $CellContext`t) Sin[$CellContext`t]}, $CellContext`u$$ = 0, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`curve$$], {
       2 E^((-0.2) $CellContext`t) Cos[$CellContext`t], 2 
        E^((-0.2) $CellContext`t) Sin[$CellContext`t]}, "Curve formula"}}, {{
       Hold[$CellContext`a$$], 0, "Parameter start value"}}, {{
       Hold[$CellContext`b$$], 4 Pi, "Parameter end value"}}, {{
       Hold[$CellContext`u$$], 0, "Point slider"}, 0, 1, 0.01}}, 
    Typeset`size$$ = {344., {246.21875, 252.78125}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`u$40553$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0, $CellContext`b$$ = 
        4 Pi, $CellContext`curve$$ = {
         2 E^((-0.2) $CellContext`t) Cos[$CellContext`t], 2 
          E^((-0.2) $CellContext`t) Sin[$CellContext`t]}, $CellContext`u$$ = 
        0}, "ControllerVariables" :> {
        Hold[$CellContext`u$$, $CellContext`u$40553$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`OsculatingCirclein2D[$CellContext`curve$$, \
{$CellContext`t, $CellContext`a$$, $CellContext`b$$}, $CellContext`a$$ + \
$CellContext`u$$ ($CellContext`b$$ - $CellContext`a$$)], 
      "Specifications" :> {{{$CellContext`curve$$, {
          2 E^((-0.2) $CellContext`t) Cos[$CellContext`t], 2 
           E^((-0.2) $CellContext`t) Sin[$CellContext`t]}, 
          "Curve formula"}}, {{$CellContext`a$$, 0, 
          "Parameter start value"}}, {{$CellContext`b$$, 4 Pi, 
          "Parameter end value"}}, {{$CellContext`u$$, 0, "Point slider"}, 0, 
         1, 0.01}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{423., {350.21875, 356.78125}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`OsculatingCirclein2D[
         Pattern[$CellContext`curve, 
          Blank[]], {
          Pattern[$CellContext`t, 
           Blank[]], 
          Pattern[$CellContext`a, 
           Blank[]], 
          Pattern[$CellContext`b, 
           Blank[]]}, 
         Pattern[$CellContext`t0, 
          Blank[]]] := 
       Block[{$CellContext`curvature, $CellContext`radius, \
$CellContext`center, $CellContext`graphics, $CellContext`k, $CellContext`x, \
$CellContext`y, $CellContext`xmin, $CellContext`xmax, $CellContext`ymin, \
$CellContext`ymax, $CellContext`pts, $CellContext`r, $CellContext`normal, \
$CellContext`n, $CellContext`tangent, $CellContext`ptoncurve, \
$CellContext`maxcurvature}, $CellContext`x = 
          Part[$CellContext`curve, 1]; $CellContext`y = 
          Part[$CellContext`curve, 2]; $CellContext`curvature = 
          Abs[D[$CellContext`x, $CellContext`t] 
              D[$CellContext`y, $CellContext`t, $CellContext`t] - 
             D[$CellContext`y, $CellContext`t] 
             D[$CellContext`x, $CellContext`t, $CellContext`t]]/(
            D[$CellContext`x, $CellContext`t]^2 + 
            D[$CellContext`y, $CellContext`t]^2)^(3/2); $CellContext`tangent = 
          D[$CellContext`curve, $CellContext`t]/Sqrt[
            Dot[
             D[$CellContext`curve, $CellContext`t], 
             D[$CellContext`curve, $CellContext`t]]]; $CellContext`normal = 
          D[$CellContext`tangent, $CellContext`t]/Sqrt[
            Dot[
             D[$CellContext`tangent, $CellContext`t], 
             D[$CellContext`tangent, $CellContext`t]]]; $CellContext`radius = 
          1/$CellContext`curvature; $CellContext`pts = Transpose[
            
            Table[$CellContext`curve, {$CellContext`t, $CellContext`a, \
$CellContext`b, ($CellContext`b - $CellContext`a)/
              50}]]; {$CellContext`xmin, $CellContext`xmax} = {Min[
              Part[$CellContext`pts, 1]] - 0.5, Max[
              Part[$CellContext`pts, 1]] + 
            0.5}; {$CellContext`ymin, $CellContext`ymax} = {Min[
              Part[$CellContext`pts, 2]] - 0.5, Max[
              Part[$CellContext`pts, 2]] + 0.5}; $CellContext`maxcurvature = 
          Max[
             
             Table[$CellContext`curvature, {$CellContext`t, $CellContext`a, \
$CellContext`b, ($CellContext`b - $CellContext`a)/50}]] + 0.5; $CellContext`r = 
          ReplaceAll[$CellContext`radius, $CellContext`t -> $CellContext`t0]; \
$CellContext`n = 
          ReplaceAll[$CellContext`normal, $CellContext`t -> $CellContext`t0]; \
$CellContext`k = 
          ReplaceAll[$CellContext`curvature, $CellContext`t -> \
$CellContext`t0]; $CellContext`ptoncurve = 
          ReplaceAll[$CellContext`curve, $CellContext`t -> $CellContext`t0]; \
$CellContext`center = $CellContext`ptoncurve + (
             1/$CellContext`k) $CellContext`n; $CellContext`graphics = {
            PointSize[0.03], 
            Point[$CellContext`ptoncurve], Red, 
            Point[$CellContext`ptoncurve + (1/$CellContext`k) $CellContext`n], 
            Circle[$CellContext`center, $CellContext`r], 
            Line[{$CellContext`ptoncurve, $CellContext`center}]}; Column[{
            Show[
             
             ParametricPlot[$CellContext`curve, {$CellContext`t, \
$CellContext`a, $CellContext`b}, PlotLabel -> 
              StringJoin["The current point is ", 
                ToString[
                 Chop[$CellContext`ptoncurve]]]], 
             Graphics[$CellContext`graphics], 
             PlotRange -> {{$CellContext`xmin, $CellContext`xmax}, \
{$CellContext`ymin, $CellContext`ymax}}, AspectRatio -> Automatic, ImageSize -> 
             275], 
            Show[
             
             Plot[$CellContext`curvature, {$CellContext`t, $CellContext`a, \
$CellContext`b}, PlotLabel -> StringJoin["The current curvature is ", 
                ToString[$CellContext`k]]], 
             Graphics[{Red, 
               
               Line[{{$CellContext`t0, 
                  0}, {$CellContext`t0, $CellContext`maxcurvature}}]}], 
             ImageSize -> 225]}]]}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.492254375238317*^9, 3.492254397396867*^9}, {
   3.492254445088365*^9, 3.4922544511472178`*^9}, 3.492254511820304*^9, {
   3.492254551229225*^9, 3.49225458195929*^9}, {3.492254615758233*^9, 
   3.4922546626667957`*^9}, 3.4922547076376333`*^9, 3.492254757275145*^9, 
   3.492254967748764*^9, {3.492255027625605*^9, 3.492255070653061*^9}, 
   3.492258576395851*^9, 3.4922586165074797`*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{646, 800},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 99, 1, 57, "Subtitle"],
Cell[669, 25, 1249, 27, 220, "Text"],
Cell[1921, 54, 8922, 217, 23, "Input",
 CellOpen->False],
Cell[CellGroupData[{
Cell[10868, 275, 1608, 46, 23, "Input",
 CellOpen->False],
Cell[12479, 323, 7230, 139, 727, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
