(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     26191,        637]
NotebookOptionsPosition[     25676,        614]
NotebookOutlinePosition[     26014,        629]
CellTagsIndexPosition[     25971,        626]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Example 7.3.1", "Subtitle",
 CellChangeTimes->{{3.476101680806065*^9, 3.4761016911290283`*^9}, {
  3.4922523859284277`*^9, 3.492252389126549*^9}}],

Cell[TextData[{
 "This manipulation illustrates the TNB frame (unit tangent vector, unit \
normal vector, unit binormal vector) to a curve in three dimensional space. \
Simply enter in your curve formula (which must be a function of ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]]],
 ", so don't use ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]]],
 " as a variable elsewhere!) and  the range of ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]]],
 "-values for the curve to be shown in the graph.  You can then move the TNB \
frame along the curve using the provided slider, enter in a specific ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]]],
 "-value, and select to show or hide any of the three vectors.\n\nThe unit \
tangent vector is shown in red, the unit normal vector is blue, and the unit \
binormal vector is in green.\n\nYou can rotate the graph as you would any \
three-dimensional ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " graphic."
}], "Text",
 CellChangeTimes->{{3.4761016977978*^9, 3.476101726389536*^9}, {
  3.47610175742883*^9, 3.476101782497065*^9}, {3.476110736545946*^9, 
  3.476111012460999*^9}, {3.476111043838533*^9, 3.4761111063465233`*^9}, {
  3.492252415063553*^9, 3.492252685415348*^9}, {3.492252780226527*^9, 
  3.4922528086471663`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"TNBFrame", "[", 
     RowBox[{"r_", ",", " ", 
      RowBox[{"{", 
       RowBox[{"t_", ",", "a_", ",", "b_"}], "}"}], ",", "u_", ",", "t1_", 
      ",", "valflag_", ",", "tflag_", ",", "nflag_", ",", "bflag_"}], "]"}], ":=",
     "\[IndentingNewLine]", 
    RowBox[{"Block", "[", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "rx", ",", "ry", ",", "rz", ",", "dr", ",", "tan", ",", "norm", ",", 
        "binorm", ",", "xmin", ",", "xmax", ",", "ymin", ",", "ymax", ",", 
        "zmin", ",", "zmax", ",", "sorted", ",", "tval", ",", "parts", ",", 
        "point"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{
        "Define", " ", "the", " ", "components", " ", "of", " ", "r"}], ",", 
        " ", 
        RowBox[{"the", " ", "\"\<t-value\>\""}], ",", " ", 
        RowBox[{"and", " ", "the", " ", "point"}]}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"rx", "=", 
        RowBox[{"r", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"ry", "=", 
        RowBox[{"r", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"rz", "=", 
        RowBox[{"r", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tval", "=", 
        RowBox[{"If", " ", "[", 
         RowBox[{"valflag", ",", "t1", ",", 
          RowBox[{"a", "+", 
           RowBox[{"u", 
            RowBox[{"(", 
             RowBox[{"b", "-", "a"}], ")"}]}]}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"point", "=", 
        RowBox[{"N", "[", 
         RowBox[{"r", " ", "/.", " ", 
          RowBox[{"t", "\[Rule]", "tval"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Determine", " ", "ranges", " ", "for", " ", "the", " ", "plot"}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"sorted", "=", 
        RowBox[{"Union", "[", " ", 
         RowBox[{"Table", "[", 
          RowBox[{"rx", ",", 
           RowBox[{"{", 
            RowBox[{"t", ",", "a", ",", "b", ",", ".01"}], "}"}]}], "]"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xmin", ",", "xmax"}], "}"}], "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"sorted", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
          RowBox[{
           RowBox[{"sorted", "[", 
            RowBox[{"[", 
             RowBox[{"-", "1"}], "]"}], "]"}], "+", "1"}]}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"sorted", "=", 
        RowBox[{"Union", "[", " ", 
         RowBox[{"Table", "[", " ", 
          RowBox[{"ry", ",", 
           RowBox[{"{", 
            RowBox[{"t", ",", "a", ",", "b", ",", ".01"}], "}"}]}], "]"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"ymin", ",", "ymax"}], "}"}], "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"sorted", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
          RowBox[{
           RowBox[{"sorted", "[", 
            RowBox[{"[", 
             RowBox[{"-", "1"}], "]"}], "]"}], "+", "1"}]}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"sorted", "=", 
        RowBox[{"Union", "[", " ", 
         RowBox[{"Table", "[", 
          RowBox[{"rz", ",", 
           RowBox[{"{", 
            RowBox[{"t", ",", "a", ",", "b", ",", ".01"}], "}"}]}], "]"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"zmin", ",", "zmax"}], "}"}], "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"sorted", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
          RowBox[{
           RowBox[{"sorted", "[", 
            RowBox[{"[", 
             RowBox[{"-", "1"}], "]"}], "]"}], "+", "1"}]}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"Create", " ", "the", " ", "TNB", " ", "vectors"}], " ", 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"tan", "=", 
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{"r", ",", "t"}], "]"}], "/", 
          RowBox[{"Sqrt", "[", " ", 
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{"r", ",", "t"}], "]"}], ".", 
            RowBox[{"D", "[", 
             RowBox[{"r", ",", "t"}], "]"}]}], "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"norm", "=", 
        RowBox[{"Evaluate", "[", " ", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{"tan", ",", "t"}], "]"}], "/", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{"tan", ",", "t"}], "]"}], ".", 
            RowBox[{"D", "[", 
             RowBox[{"tan", ",", "t"}], "]"}]}], "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"binorm", "=", 
        RowBox[{"Cross", "[", 
         RowBox[{"tan", ",", "norm"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"Create", " ", "the", " ", "raw", " ", "graphics"}], " ", 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"parts", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{"{", " ", 
          RowBox[{
           RowBox[{"PointSize", "[", ".02", "]"}], ",", " ", 
           RowBox[{"Point", "[", "point", "]"}], ",", " ", "Red", ",", 
           RowBox[{"If", "[", 
            RowBox[{"tflag", ",", 
             RowBox[{"Arrow", "[", " ", 
              RowBox[{"{", 
               RowBox[{"point", ",", 
                RowBox[{"point", "+", 
                 RowBox[{"(", 
                  RowBox[{"tan", "/.", " ", 
                   RowBox[{"t", "\[Rule]", "tval"}]}], ")"}]}]}], "}"}], 
              "]"}], ",", 
             RowBox[{"{", "}"}]}], "]"}], ",", "Blue", ",", 
           RowBox[{"If", "[", 
            RowBox[{"nflag", ",", 
             RowBox[{"Arrow", "[", 
              RowBox[{"{", 
               RowBox[{"point", ",", 
                RowBox[{"point", "+", 
                 RowBox[{"(", 
                  RowBox[{"norm", "/.", " ", 
                   RowBox[{"t", "\[Rule]", " ", "tval"}]}], ")"}]}]}], "}"}], 
              "]"}], ",", 
             RowBox[{"{", "}"}]}], "]"}], ",", " ", 
           RowBox[{"Darker", "[", "Green", "]"}], ",", " ", 
           RowBox[{"If", "[", 
            RowBox[{"bflag", ",", " ", 
             RowBox[{"Arrow", "[", 
              RowBox[{"{", 
               RowBox[{"point", ",", " ", 
                RowBox[{"point", "+", 
                 RowBox[{"(", 
                  RowBox[{"binorm", "/.", " ", 
                   RowBox[{"t", "\[Rule]", "tval"}]}], ")"}]}]}], "}"}], 
              "]"}], ",", 
             RowBox[{"{", "}"}]}], "]"}]}], "}"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"Create", "/", "display"}], " ", "the", " ", "final", " ", 
         "graphic"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Show", "[", " ", 
        RowBox[{
         RowBox[{"ParametricPlot3D", "[", 
          RowBox[{"r", ",", 
           RowBox[{"{", 
            RowBox[{"t", ",", "a", ",", "b"}], "}"}], ",", " ", 
           RowBox[{"AxesLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\""}], 
             "}"}]}], ",", " ", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"ymin", ",", "ymax"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"zmin", ",", "zmax"}], "}"}]}], "}"}]}]}], "]"}], ",", 
         " ", 
         RowBox[{"Graphics3D", "[", "parts", "]"}]}], " ", "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]"}]], "Input",\

 CellOpen->False,
 CellChangeTimes->{{3.4760999097097187`*^9, 3.476100758544387*^9}, {
  3.476100877789814*^9, 3.4761010549603977`*^9}, {3.476101087265738*^9, 
  3.4761011399241667`*^9}, {3.476101405541555*^9, 3.4761014059323597`*^9}, {
  3.4761018012718678`*^9, 3.476101834023222*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", " ", 
  RowBox[{
   RowBox[{"TNBFrame", "[", " ", 
    RowBox[{"r", ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "a", ",", "b"}], "}"}], ",", "u", ",", "t1", ",", 
     "valflag", ",", "tflag", ",", "nflag", ",", "bflag"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"r", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"3", "t"}], "]"}], ",", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", "t"}], "]"}], ",", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", "t"}], "]"}]}], "}"}], ",", 
      "\"\<Curve Formula in {x,y,z} format\>\""}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"a", ",", "0", ",", "\"\<Starting t-value\>\""}], "}"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"b", ",", 
      RowBox[{"2", "Pi"}], ",", " ", "\"\<Final t-value\>\""}], "}"}], "}"}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "valflag", ",", "False", ",", 
       "\"\<Use the value below rather than the slider\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
     "t1", ",", "Pi", ",", "\"\<Plot the frame at the specific value\>\""}], 
     "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"u", ",", "0", ",", "\"\<Point Slider\>\""}], "}"}], ",", "0", 
     ",", "1", ",", ".01"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tflag", ",", "True", ",", "\"\<Show Unit Tangent Vector\>\""}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"nflag", ",", "True", ",", "\"\<Show Unit Normal Vector\>\""}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "bflag", ",", "True", ",", "\"\<Show Unit Binormal Vector\>\""}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ",", 
   RowBox[{"ControlPlacement", "\[Rule]", " ", "Top"}], ",", " ", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.476101167270116*^9, 3.476101441814847*^9}, {
  3.476101484682598*^9, 3.476101485546361*^9}, {3.476101529882538*^9, 
  3.476101530970799*^9}, {3.476101563068911*^9, 3.476101570130685*^9}, {
  3.4761018662306547`*^9, 3.4761019551705236`*^9}, {3.4761020166994457`*^9, 
  3.476102042138955*^9}, {3.4761020820249643`*^9, 3.476102090195685*^9}, {
  3.492252312132146*^9, 3.492252349728776*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0, $CellContext`b$$ = 2 
    Pi, $CellContext`bflag$$ = True, $CellContext`nflag$$ = 
    True, $CellContext`r$$ = {
     Cos[3 $CellContext`t], 
     Sin[2 $CellContext`t], 
     Cos[2 $CellContext`t]}, $CellContext`t1$$ = Pi, $CellContext`tflag$$ = 
    True, $CellContext`u$$ = 0., $CellContext`valflag$$ = False, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`r$$], {
        Cos[3 $CellContext`t], 
        Sin[2 $CellContext`t], 
        Cos[2 $CellContext`t]}, "Curve Formula in {x,y,z} format"}}, {{
       Hold[$CellContext`a$$], 0, "Starting t-value"}}, {{
       Hold[$CellContext`b$$], 2 Pi, "Final t-value"}}, {{
       Hold[$CellContext`valflag$$], False, 
       "Use the value below rather than the slider"}, {True, False}}, {{
       Hold[$CellContext`t1$$], Pi, 
       "Plot the frame at the specific value"}}, {{
       Hold[$CellContext`u$$], 0, "Point Slider"}, 0, 1, 0.01}, {{
       Hold[$CellContext`tflag$$], True, "Show Unit Tangent Vector"}, {
      True, False}}, {{
       Hold[$CellContext`nflag$$], True, "Show Unit Normal Vector"}, {
      True, False}}, {{
       Hold[$CellContext`bflag$$], True, "Show Unit Binormal Vector"}, {
      True, False}}}, Typeset`size$$ = {450., {254., 260.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`valflag$782$$ = False, $CellContext`u$783$$ = 
    0, $CellContext`tflag$784$$ = False, $CellContext`nflag$785$$ = 
    False, $CellContext`bflag$786$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0, $CellContext`b$$ = 
        2 Pi, $CellContext`bflag$$ = True, $CellContext`nflag$$ = 
        True, $CellContext`r$$ = {
          Cos[3 $CellContext`t], 
          Sin[2 $CellContext`t], 
          Cos[2 $CellContext`t]}, $CellContext`t1$$ = 
        Pi, $CellContext`tflag$$ = True, $CellContext`u$$ = 
        0, $CellContext`valflag$$ = False}, "ControllerVariables" :> {
        Hold[$CellContext`valflag$$, $CellContext`valflag$782$$, False], 
        Hold[$CellContext`u$$, $CellContext`u$783$$, 0], 
        Hold[$CellContext`tflag$$, $CellContext`tflag$784$$, False], 
        Hold[$CellContext`nflag$$, $CellContext`nflag$785$$, False], 
        Hold[$CellContext`bflag$$, $CellContext`bflag$786$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`TNBFrame[$CellContext`r$$, {$CellContext`t, \
$CellContext`a$$, $CellContext`b$$}, $CellContext`u$$, $CellContext`t1$$, \
$CellContext`valflag$$, $CellContext`tflag$$, $CellContext`nflag$$, \
$CellContext`bflag$$], "Specifications" :> {{{$CellContext`r$$, {
           Cos[3 $CellContext`t], 
           Sin[2 $CellContext`t], 
           Cos[2 $CellContext`t]}, 
          "Curve Formula in {x,y,z} format"}}, {{$CellContext`a$$, 0, 
          "Starting t-value"}}, {{$CellContext`b$$, 2 Pi, 
          "Final t-value"}}, {{$CellContext`valflag$$, False, 
          "Use the value below rather than the slider"}, {
         True, False}}, {{$CellContext`t1$$, Pi, 
          "Plot the frame at the specific value"}}, {{$CellContext`u$$, 0, 
          "Point Slider"}, 0, 1, 
         0.01}, {{$CellContext`tflag$$, True, "Show Unit Tangent Vector"}, {
         True, False}}, {{$CellContext`nflag$$, True, 
          "Show Unit Normal Vector"}, {
         True, False}}, {{$CellContext`bflag$$, True, 
          "Show Unit Binormal Vector"}, {True, False}}}, 
      "Options" :> {ControlPlacement -> Top}, "DefaultOptions" :> {}],
     ImageSizeCache->{536., {430.21875, 436.78125}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`TNBFrame[
         Pattern[$CellContext`r, 
          Blank[]], {
          Pattern[$CellContext`t, 
           Blank[]], 
          Pattern[$CellContext`a, 
           Blank[]], 
          Pattern[$CellContext`b, 
           Blank[]]}, 
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`tflag, 
          Blank[]], 
         Pattern[$CellContext`nflag, 
          Blank[]], 
         Pattern[$CellContext`bflag, 
          Blank[]]] := 
       Block[{$CellContext`rx, $CellContext`ry, $CellContext`rz, \
$CellContext`dr, $CellContext`tan, $CellContext`norm, $CellContext`binorm, \
$CellContext`xmin, $CellContext`xmax, $CellContext`ymin, $CellContext`ymax, \
$CellContext`zmin, $CellContext`zmax, $CellContext`sorted, $CellContext`tval, \
$CellContext`parts, $CellContext`point}, $CellContext`rx = 
          Part[$CellContext`r, 1]; $CellContext`ry = 
          Part[$CellContext`r, 2]; $CellContext`rz = 
          Part[$CellContext`r, 
            3]; $CellContext`tval = $CellContext`a + $CellContext`u \
($CellContext`b - $CellContext`a); $CellContext`point = N[
            
            ReplaceAll[$CellContext`r, $CellContext`t -> $CellContext`tval]]; \
$CellContext`sorted = Union[
            
            Table[$CellContext`rx, {$CellContext`t, $CellContext`a, \
$CellContext`b, 0.01}]]; {$CellContext`xmin, $CellContext`xmax} = {
           Part[$CellContext`sorted, 1] - 1, Part[$CellContext`sorted, -1] + 
            1}; $CellContext`sorted = Union[
            
            Table[$CellContext`ry, {$CellContext`t, $CellContext`a, \
$CellContext`b, 0.01}]]; {$CellContext`ymin, $CellContext`ymax} = {
           Part[$CellContext`sorted, 1] - 1, Part[$CellContext`sorted, -1] + 
            1}; $CellContext`sorted = Union[
            
            Table[$CellContext`rz, {$CellContext`t, $CellContext`a, \
$CellContext`b, 0.01}]]; {$CellContext`zmin, $CellContext`zmax} = {
           Part[$CellContext`sorted, 1] - 1, Part[$CellContext`sorted, -1] + 
            1}; $CellContext`tan = 
          Evaluate[D[$CellContext`r, $CellContext`t]/Sqrt[
             Dot[
              D[$CellContext`r, $CellContext`t], 
              D[$CellContext`r, $CellContext`t]]]]; $CellContext`norm = 
          Evaluate[D[$CellContext`tan, $CellContext`t]/Sqrt[
             Dot[
              D[$CellContext`tan, $CellContext`t], 
              D[$CellContext`tan, $CellContext`t]]]]; $CellContext`binorm = 
          Cross[$CellContext`tan, $CellContext`norm]; $CellContext`parts = 
          Flatten[{
             PointSize[0.02], 
             Point[$CellContext`point], Red, 
             If[$CellContext`tflag, 
              
              Arrow[{$CellContext`point, $CellContext`point + 
                ReplaceAll[$CellContext`tan, $CellContext`t -> \
$CellContext`tval]}], {}], Blue, 
             If[$CellContext`nflag, 
              
              Arrow[{$CellContext`point, $CellContext`point + 
                ReplaceAll[$CellContext`norm, $CellContext`t -> \
$CellContext`tval]}], {}], 
             Darker[Green], 
             If[$CellContext`bflag, 
              
              Arrow[{$CellContext`point, $CellContext`point + 
                ReplaceAll[$CellContext`binorm, $CellContext`t -> \
$CellContext`tval]}], {}]}]; Show[
           
           ParametricPlot3D[$CellContext`r, {$CellContext`t, $CellContext`a, \
$CellContext`b}, AxesLabel -> {"x", "y", "z"}, 
            PlotRange -> {{$CellContext`xmin, $CellContext`xmax}, \
{$CellContext`ymin, $CellContext`ymax}, {$CellContext`zmin, \
$CellContext`zmax}}], 
           Graphics3D[$CellContext`parts]]], $CellContext`TNBFrame[
         Pattern[$CellContext`r, 
          Blank[]], {
          Pattern[$CellContext`t, 
           Blank[]], 
          Pattern[$CellContext`a, 
           Blank[]], 
          Pattern[$CellContext`b, 
           Blank[]]}, 
         Pattern[$CellContext`u, 
          Blank[]], 
         Pattern[$CellContext`t1, 
          Blank[]], 
         Pattern[$CellContext`valflag, 
          Blank[]], 
         Pattern[$CellContext`tflag, 
          Blank[]], 
         Pattern[$CellContext`nflag, 
          Blank[]], 
         Pattern[$CellContext`bflag, 
          Blank[]]] := 
       Block[{$CellContext`rx, $CellContext`ry, $CellContext`rz, \
$CellContext`dr, $CellContext`tan, $CellContext`norm, $CellContext`binorm, \
$CellContext`xmin, $CellContext`xmax, $CellContext`ymin, $CellContext`ymax, \
$CellContext`zmin, $CellContext`zmax, $CellContext`sorted, $CellContext`tval, \
$CellContext`parts, $CellContext`point}, $CellContext`rx = 
          Part[$CellContext`r, 1]; $CellContext`ry = 
          Part[$CellContext`r, 2]; $CellContext`rz = 
          Part[$CellContext`r, 3]; $CellContext`tval = 
          If[$CellContext`valflag, $CellContext`t1, $CellContext`a + \
$CellContext`u ($CellContext`b - $CellContext`a)]; $CellContext`point = N[
            
            ReplaceAll[$CellContext`r, $CellContext`t -> $CellContext`tval]]; \
$CellContext`sorted = Union[
            
            Table[$CellContext`rx, {$CellContext`t, $CellContext`a, \
$CellContext`b, 0.01}]]; {$CellContext`xmin, $CellContext`xmax} = {
           Part[$CellContext`sorted, 1] - 1, Part[$CellContext`sorted, -1] + 
            1}; $CellContext`sorted = Union[
            
            Table[$CellContext`ry, {$CellContext`t, $CellContext`a, \
$CellContext`b, 0.01}]]; {$CellContext`ymin, $CellContext`ymax} = {
           Part[$CellContext`sorted, 1] - 1, Part[$CellContext`sorted, -1] + 
            1}; $CellContext`sorted = Union[
            
            Table[$CellContext`rz, {$CellContext`t, $CellContext`a, \
$CellContext`b, 0.01}]]; {$CellContext`zmin, $CellContext`zmax} = {
           Part[$CellContext`sorted, 1] - 1, Part[$CellContext`sorted, -1] + 
            1}; $CellContext`tan = 
          Evaluate[D[$CellContext`r, $CellContext`t]/Sqrt[
             Dot[
              D[$CellContext`r, $CellContext`t], 
              D[$CellContext`r, $CellContext`t]]]]; $CellContext`norm = 
          Evaluate[D[$CellContext`tan, $CellContext`t]/Sqrt[
             Dot[
              D[$CellContext`tan, $CellContext`t], 
              D[$CellContext`tan, $CellContext`t]]]]; $CellContext`binorm = 
          Cross[$CellContext`tan, $CellContext`norm]; $CellContext`parts = 
          Flatten[{
             PointSize[0.02], 
             Point[$CellContext`point], Red, 
             If[$CellContext`tflag, 
              
              Arrow[{$CellContext`point, $CellContext`point + 
                ReplaceAll[$CellContext`tan, $CellContext`t -> \
$CellContext`tval]}], {}], Blue, 
             If[$CellContext`nflag, 
              
              Arrow[{$CellContext`point, $CellContext`point + 
                ReplaceAll[$CellContext`norm, $CellContext`t -> \
$CellContext`tval]}], {}], 
             Darker[Green], 
             If[$CellContext`bflag, 
              
              Arrow[{$CellContext`point, $CellContext`point + 
                ReplaceAll[$CellContext`binorm, $CellContext`t -> \
$CellContext`tval]}], {}]}]; Show[
           
           ParametricPlot3D[$CellContext`r, {$CellContext`t, $CellContext`a, \
$CellContext`b}, AxesLabel -> {"x", "y", "z"}, 
            PlotRange -> {{$CellContext`xmin, $CellContext`xmax}, \
{$CellContext`ymin, $CellContext`ymax}, {$CellContext`zmin, \
$CellContext`zmax}}], 
           Graphics3D[$CellContext`parts]]]}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.476101392281692*^9, 3.476101442678597*^9}, 
   3.476101492311769*^9, 3.4761015316710253`*^9, 3.476101589260889*^9, 
   3.476101652887645*^9, {3.476101958680725*^9, 3.476101964774229*^9}, {
   3.476102022226508*^9, 3.4761020426700706`*^9}, {3.476102082905669*^9, 
   3.476102090982017*^9}, 3.476110773795107*^9, {3.492252331373407*^9, 
   3.4922523529581623`*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{798, 868},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 152, 2, 57, "Subtitle"],
Cell[722, 26, 1292, 28, 182, "Text"],
Cell[2017, 56, 8534, 218, 23, "Input",
 CellOpen->False],
Cell[CellGroupData[{
Cell[10576, 278, 2819, 78, 23, "Input",
 CellOpen->False],
Cell[13398, 358, 12250, 252, 887, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
