(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     22656,        558]
NotebookOptionsPosition[     22097,        534]
NotebookOutlinePosition[     22438,        549]
CellTagsIndexPosition[     22395,        546]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Example 8.4.1", "Subtitle",
 CellChangeTimes->{{3.493394660203555*^9, 3.493394662633766*^9}}],

Cell[TextData[{
 "This notebook contains the interactive manipulation for example 8.4.1 of \
the text, the projection of a vector onto a subspace.  The idea is to take 2 \
vectors ",
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    SubscriptBox["b", "1"], "\[RightVector]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and  ",
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    SubscriptBox["b", "2"], "\[RightVector]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " which are the basis for two-dimensional subspace in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckCapitalR]", "3"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and a vector ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["v", "\[RightVector]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", and find the projection of ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["v", "\[RightVector]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " onto the subspace as well as the component of ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["v", "\[RightVector]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " which is orthogonal to the subspace.\n\nFor the manipulation, enter the \
vectors  ",
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    SubscriptBox["b", "1"], "\[RightVector]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and  ",
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    SubscriptBox["b", "2"], "\[RightVector]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " (these will appear in blue and purple) and the vector ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["v", "\[RightVector]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " (which will appear in orange).  The manipulation will then plot the \
subspace (transparent blue plane) as well as the projection of ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["v", "\[RightVector]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " onto the subspace (in yellow) and the part of ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["v", "\[RightVector]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " that is orthogonal to the subspace (in red). It will also give the \
component form of both parts of ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["v", "\[RightVector]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ".  You may freely rotate the picture; the direction in which the vector ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["v", "\[RightVector]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " is projected is slightly shaded to aid in perspective.\n\nFor \
completeness, the manipulation will check to make sure that ",
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    SubscriptBox["b", "1"], "\[RightVector]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and  ",
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    SubscriptBox["b", "2"], "\[RightVector]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " are linearly independent."
}], "Text",
 CellChangeTimes->{{3.493394665690117*^9, 3.493395170932542*^9}, {
  3.493395261564919*^9, 3.4933952619576807`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"VectorProject3D", "[", " ", 
    RowBox[{"b1_", ",", " ", "b2_", ",", " ", "v_"}], "]"}], ":=", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Block", "[", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "normal", ",", " ", "projonnormal", ",", "projinplane", ",", " ", "max",
        ",", "rawgraphics", ",", "t", ",", "u"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Cross", "[", 
          RowBox[{"b1", ",", "b2"}], "]"}], "\[Equal]", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], ",", " ", 
        RowBox[{
         RowBox[{
         "Print", "[", "\"\<The vectors entered no not form a basis\>\"", 
          "]"}], ";", 
         RowBox[{"Return", "[", "]"}]}]}], " ", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"max", "=", 
       RowBox[{
        RowBox[{"Max", "[", 
         RowBox[{
          RowBox[{"Norm", "[", "b1", "]"}], ",", 
          RowBox[{"Norm", "[", "b2", "]"}], ",", 
          RowBox[{"Norm", "[", "v", "]"}]}], "]"}], "+", ".5"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"normal", "=", 
       RowBox[{"Cross", "[", 
        RowBox[{"b1", ",", "b2"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"projonnormal", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"v", ".", "normal"}], "/", 
         RowBox[{
          RowBox[{"Norm", "[", "normal", "]"}], "^", "2"}]}], " ", 
        "normal"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"projinplane", "=", 
       RowBox[{"v", "-", "projonnormal"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"rawgraphics", "=", 
       RowBox[{"{", 
        RowBox[{"Thick", ",", "Blue", ",", " ", 
         RowBox[{"Arrow", "[", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "b1"}], "}"}], 
          "]"}], ",", " ", "Purple", ",", " ", 
         RowBox[{"Arrow", "[", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "b2"}], "}"}], 
          "]"}], ",", " ", "Orange", ",", 
         RowBox[{"Arrow", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "v"}], "}"}], 
          "]"}], ",", "Yellow", ",", " ", 
         RowBox[{"Arrow", "[", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", " ", 
            "projinplane"}], "}"}], "]"}], ",", " ", "Red", ",", 
         RowBox[{"Arrow", "[", " ", 
          RowBox[{"{", 
           RowBox[{"projinplane", ",", "v"}], "}"}], "]"}], ",", " ", "Red", 
         ",", " ", 
         RowBox[{"Opacity", "[", ".1", "]"}], ",", 
         RowBox[{"Polygon", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", " ", 
            "projinplane", ",", "v"}], "}"}], "]"}]}], " ", "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Column", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Row", "[", 
          RowBox[{"{", 
           RowBox[{
           "\"\<The projection of \>\"", ",", "v", ",", " ", 
            "\"\< onto the subspace is \>\"", ",", " ", "projinplane", ",", 
            "\"\<.\>\""}], "}"}], "]"}], ",", 
         RowBox[{"Row", "[", 
          RowBox[{"{", 
           RowBox[{
           "\"\<The component of \>\"", ",", " ", "v", ",", " ", 
            "\"\< orthogonal to the subspace is \>\"", ",", "projonnormal", 
            ",", "\"\<.\>\""}], "}"}], "]"}], ",", 
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"Graphics3D", "[", "rawgraphics", "]"}], ",", " ", 
           RowBox[{"ParametricPlot3D", "[", " ", 
            RowBox[{
             RowBox[{
              RowBox[{"t", " ", "b1"}], " ", "+", " ", 
              RowBox[{"u", " ", "b2"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"t", ",", 
               RowBox[{
                RowBox[{"-", "2"}], " ", "max"}], ",", 
               RowBox[{"2", "max"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"u", ",", 
               RowBox[{
                RowBox[{"-", "2"}], " ", "max"}], ",", 
               RowBox[{"2", " ", "max"}]}], "}"}], ",", " ", 
             RowBox[{"Mesh", "\[Rule]", "False"}], ",", " ", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"Blue", ",", 
                RowBox[{"Opacity", "[", ".3", "]"}]}], "}"}]}]}], "]"}], ",", 
           
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "max"}], ",", "max"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "max"}], ",", "max"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "max"}], ",", "max"}], "}"}]}], "}"}]}], ",", 
           " ", 
           RowBox[{"Axes", "\[Rule]", "True"}], ",", " ", 
           RowBox[{"AxesLabel", "\[Rule]", " ", 
            RowBox[{"{", 
             RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\""}], 
             "}"}]}], ",", " ", 
           RowBox[{"AxesEdge", "\[Rule]", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", 
                RowBox[{"-", "1"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", 
                RowBox[{"-", "1"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]}], "}"}]}], ",", " ", 
           RowBox[{"ImageSize", "->", "400"}]}], "]"}]}], "}"}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.4930321559491158`*^9, 3.493032528808835*^9}, 
   3.493032614932232*^9, {3.4930326478078938`*^9, 3.493032656366395*^9}, {
   3.493032702848156*^9, 3.493032826800988*^9}, {3.493032881750712*^9, 
   3.493032911660797*^9}, {3.49304277481569*^9, 3.4930428426486177`*^9}, {
   3.493042904813287*^9, 3.493042996137835*^9}, {3.493043129418943*^9, 
   3.493043172233842*^9}, {3.4930432535447493`*^9, 3.4930432860541077`*^9}, {
   3.4930433665535107`*^9, 3.493043387561111*^9}, {3.493043423304882*^9, 
   3.493043439951378*^9}, {3.493043474218338*^9, 3.493043529887763*^9}, {
   3.4933936785866756`*^9, 3.493393688383778*^9}, {3.493393881438526*^9, 
   3.493393889883786*^9}, {3.493393961758627*^9, 3.493393967556332*^9}, {
   3.493394108896432*^9, 3.4933941360708237`*^9}, {3.493394174741538*^9, 
   3.4933941948614817`*^9}, {3.493394267682714*^9, 3.493394381186492*^9}, {
   3.493394497069503*^9, 3.4933945280920963`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"VectorProject3D", "[", " ", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"u", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", 
         RowBox[{"-", "2"}], ",", "9"}], "}"}], ",", " ", 
       "\"\<Basis Vector 1\>\""}], "}"}], ",", " ", "InputField"}], "}"}], 
   ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"v", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3"}], ",", "7", ",", "1"}], "}"}], ",", 
       "\"\<Basis Vector 2\>\""}], "}"}], ",", "InputField"}], "}"}], ",", 
   "Delimiter", ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"w", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "8", ",", 
         RowBox[{"-", "15"}]}], "}"}], ",", "\"\<Vector to Project\>\""}], 
      "}"}], ",", "InputField"}], "}"}], ",", " ", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.4930324831176167`*^9, 3.493032494863474*^9}, 
   3.4930326700564623`*^9, {3.4933937116317472`*^9, 3.493393773655308*^9}, {
   3.49339380620087*^9, 3.493393851424465*^9}, {3.493394023460539*^9, 
   3.493394059724717*^9}, {3.493394539110779*^9, 3.4933945438691177`*^9}, {
   3.493394644150539*^9, 3.493394645589767*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`u$$ = {5, -2, 9}, $CellContext`v$$ = {-3, 7,
     1}, $CellContext`w$$ = {4, 8, -15}, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`u$$], {5, -2, 9}, "Basis Vector 1"}}, {{
       Hold[$CellContext`v$$], {-3, 7, 1}, "Basis Vector 2"}}, {{
       Hold[$CellContext`w$$], {4, 8, -15}, "Vector to Project"}}}, 
    Typeset`size$$ = {650., {296.21875, 302.78125}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`u$$ = {5, -2, 9}, $CellContext`v$$ = {-3, 
         7, 1}, $CellContext`w$$ = {4, 8, -15}}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`VectorProject3D[$CellContext`u$$, \
$CellContext`v$$, $CellContext`w$$], 
      "Specifications" :> {{{$CellContext`u$$, {5, -2, 9}, "Basis Vector 1"}, 
         ControlType -> 
         InputField}, {{$CellContext`v$$, {-3, 7, 1}, "Basis Vector 2"}, 
         ControlType -> InputField}, 
        Delimiter, {{$CellContext`w$$, {4, 8, -15}, "Vector to Project"}, 
         ControlType -> InputField}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{703., {388.21875, 394.78125}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`VectorProject3D[
         Pattern[$CellContext`b1$, 
          Blank[]], 
         Pattern[$CellContext`b2$, 
          Blank[]], 
         Pattern[$CellContext`v$, 
          Blank[]]] := 
       Block[{$CellContext`normal, $CellContext`projonnormal, \
$CellContext`projinplane, $CellContext`max, $CellContext`rawgraphics, \
$CellContext`t, FE`u$$8}, 
         If[Cross[$CellContext`b1$, $CellContext`b2$] == {0, 0, 0}, 
           Print["The vectors entered no not form a basis"]; 
           Return[]]; $CellContext`max = Max[
             Norm[$CellContext`b1$], 
             Norm[$CellContext`b2$], 
             Norm[$CellContext`v$]] + 0.5; $CellContext`normal = 
          Cross[$CellContext`b1$, $CellContext`b2$]; \
$CellContext`projonnormal = (Dot[$CellContext`v$, $CellContext`normal]/
            Norm[$CellContext`normal]^2) $CellContext`normal; \
$CellContext`projinplane = $CellContext`v$ - $CellContext`projonnormal; \
$CellContext`rawgraphics = {Thick, Blue, 
            Arrow[{{0, 0, 0}, $CellContext`b1$}], Purple, 
            Arrow[{{0, 0, 0}, $CellContext`b2$}], Orange, 
            Arrow[{{0, 0, 0}, $CellContext`v$}], Yellow, 
            Arrow[{{0, 0, 0}, $CellContext`projinplane}], Red, 
            Arrow[{$CellContext`projinplane, $CellContext`v$}], Red, 
            Opacity[0.1], 
            Polygon[{{0, 0, 0}, $CellContext`projinplane, $CellContext`v$}]}; 
         Column[{
            
            Row[{"The projection of ", $CellContext`v$, 
              " onto the subspace is ", $CellContext`projinplane, "."}], 
            
            Row[{"The component of ", $CellContext`v$, 
              " orthogonal to the subspace is ", $CellContext`projonnormal, 
              "."}], 
            Show[
             Graphics3D[$CellContext`rawgraphics], 
             
             ParametricPlot3D[$CellContext`t $CellContext`b1$ + 
              FE`u$$8 $CellContext`b2$, {$CellContext`t, (-2) \
$CellContext`max, 2 $CellContext`max}, {
              FE`u$$8, (-2) $CellContext`max, 2 $CellContext`max}, Mesh -> 
              False, PlotStyle -> {Blue, 
                Opacity[0.3]}], 
             PlotRange -> {{-$CellContext`max, $CellContext`max}, \
{-$CellContext`max, $CellContext`max}, {-$CellContext`max, $CellContext`max}},
              Axes -> True, AxesLabel -> {"x", "y", "z"}, 
             AxesEdge -> {{-1, -1}, {-1, -1}, {-1, -1}}, ImageSize -> 400]}]],
        Attributes[$CellContext`b1$] = {Temporary}, 
       Attributes[$CellContext`b2$] = {Temporary}, 
       Attributes[$CellContext`v$] = {Temporary}, FE`u$$8 = {5, 2, -9}}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.493394248814896*^9, 3.493394546541759*^9, {3.493394600889309*^9, 
   3.493394646408492*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`u$$ = {5, -2, 9}, $CellContext`v$$ = {-3, 7,
     1}, $CellContext`w$$ = {4, 8, -15}, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`u$$], {5, 2, -9}, "Basis Vector 1"}}, {{
       Hold[$CellContext`v$$], {-3, 7, 1}, "Basis Vector 2"}}, {{
       Hold[$CellContext`w$$], {4, 8, -15}, "Vector to Project"}}}, 
    Typeset`size$$ = {650., {306.21875, 312.78125}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`u$$ = {5, 2, -9}, $CellContext`v$$ = {-3, 
         7, 1}, $CellContext`w$$ = {4, 8, -15}}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`VectorProject3D[$CellContext`u$$, \
$CellContext`v$$, $CellContext`w$$], 
      "Specifications" :> {{{$CellContext`u$$, {5, 2, -9}, "Basis Vector 1"}, 
         ControlType -> 
         InputField}, {{$CellContext`v$$, {-3, 7, 1}, "Basis Vector 2"}, 
         ControlType -> InputField}, 
        Delimiter, {{$CellContext`w$$, {4, 8, -15}, "Vector to Project"}, 
         ControlType -> InputField}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{703., {398.21875, 404.78125}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`VectorProject3D[
         Pattern[$CellContext`b1$, 
          Blank[]], 
         Pattern[$CellContext`b2$, 
          Blank[]], 
         Pattern[$CellContext`v$, 
          Blank[]]] := 
       Block[{$CellContext`normal, $CellContext`projonnormal, \
$CellContext`projinplane, $CellContext`max, $CellContext`rawgraphics, \
$CellContext`t, FE`u$$8}, 
         If[Cross[$CellContext`b1$, $CellContext`b2$] == {0, 0, 0}, 
           Print["The vectors entered no not form a basis"]; 
           Return[]]; $CellContext`max = Max[
             Norm[$CellContext`b1$], 
             Norm[$CellContext`b2$], 
             Norm[$CellContext`v$]] + 0.5; $CellContext`normal = 
          Cross[$CellContext`b1$, $CellContext`b2$]; \
$CellContext`projonnormal = (Dot[$CellContext`v$, $CellContext`normal]/
            Norm[$CellContext`normal]^2) $CellContext`normal; \
$CellContext`projinplane = $CellContext`v$ - $CellContext`projonnormal; \
$CellContext`rawgraphics = {Thick, Blue, 
            Arrow[{{0, 0, 0}, $CellContext`b1$}], Purple, 
            Arrow[{{0, 0, 0}, $CellContext`b2$}], Orange, 
            Arrow[{{0, 0, 0}, $CellContext`v$}], Yellow, 
            Arrow[{{0, 0, 0}, $CellContext`projinplane}], Red, 
            Arrow[{$CellContext`projinplane, $CellContext`v$}], Red, 
            Opacity[0.1], 
            Polygon[{{0, 0, 0}, $CellContext`projinplane, $CellContext`v$}]}; 
         Column[{
            
            Row[{"The projection of ", $CellContext`v$, 
              " onto the subspace is ", $CellContext`projinplane, "."}], 
            
            Row[{"The component of ", $CellContext`v$, 
              " orthogonal to the subspace is ", $CellContext`projonnormal, 
              "."}], 
            Show[
             Graphics3D[$CellContext`rawgraphics], 
             
             ParametricPlot3D[$CellContext`t $CellContext`b1$ + 
              FE`u$$8 $CellContext`b2$, {$CellContext`t, (-2) \
$CellContext`max, 2 $CellContext`max}, {
              FE`u$$8, (-2) $CellContext`max, 2 $CellContext`max}, Mesh -> 
              False, PlotStyle -> {Blue, 
                Opacity[0.3]}], 
             PlotRange -> {{-$CellContext`max, $CellContext`max}, \
{-$CellContext`max, $CellContext`max}, {-$CellContext`max, $CellContext`max}},
              Axes -> True, AxesLabel -> {"x", "y", "z"}, 
             AxesEdge -> {{-1, -1}, {-1, -1}, {-1, -1}}, ImageSize -> 400]}]],
        Attributes[$CellContext`b1$] = {Temporary}, 
       Attributes[$CellContext`b2$] = {Temporary}, 
       Attributes[$CellContext`v$] = {Temporary}, FE`u$$8 = {5, 2, -9}}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.493394248814896*^9, 3.493394546541759*^9, {3.493394600889309*^9, 
   3.493394625206414*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{849, 1010},
WindowMargins->{{20, Automatic}, {29, Automatic}},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 99, 1, 57, "Subtitle"],
Cell[669, 25, 3145, 91, 246, "Text"],
Cell[3817, 118, 7112, 173, 23, "Input",
 CellOpen->False],
Cell[CellGroupData[{
Cell[10954, 295, 1385, 37, 23, "Input",
 CellOpen->False],
Cell[12342, 334, 4862, 97, 803, "Output"],
Cell[17207, 433, 4862, 97, 823, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
