(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     37776,       1228]
NotebookOptionsPosition[     34016,       1103]
NotebookOutlinePosition[     34360,       1118]
CellTagsIndexPosition[     34317,       1115]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Chapter 3 - Gauss-Jordan Elimination and Reduced Row Echelon Form\
\>", "Title",
 CellChangeTimes->{{3.5050609655230303`*^9, 3.5050609866840863`*^9}, 
   3.5050621526253853`*^9, 3.5051305249418364`*^9, {3.505137372192705*^9, 
   3.5051373755819635`*^9}, 3.5051381117502155`*^9, 3.505143534856351*^9}],

Cell["\<\
Section 3.3 - Sensitivity of Solutions to Error in the Linear System  \
\>", "Subtitle",
 CellChangeTimes->{{3.505061001045597*^9, 3.5050610327405024`*^9}, {
  3.505130525754035*^9, 3.505130529611977*^9}, {3.505137377706106*^9, 
  3.5051373822199106`*^9}, {3.5051385890546317`*^9, 3.505138594411812*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Example 3.3.1",
 FontWeight->"Bold"]], "Subsubtitle",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.50513860848417*^9, 3.505138625711486*^9}}],

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"6", " ", "x"}], "+", 
        RowBox[{"9", " ", "y"}]}], "\[Equal]", "5"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "x"}], "+", 
        RowBox[{"7", " ", "y"}]}], "\[Equal]", "3"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}]}], "]"}], "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.505138625711486*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", "\[Rule]", "0.13333333333333333`"}], ",", 
    RowBox[{"y", "\[Rule]", "0.4666666666666667`"}]}], "}"}], "}"}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.505138612435676*^9, 3.505138625711486*^9}}],

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"6.1", " ", "x"}], "+", 
        RowBox[{"9", " ", "y"}]}], "\[Equal]", "5"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "x"}], "+", 
        RowBox[{"7", " ", "y"}]}], "\[Equal]", "3"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}]}], "]"}], "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.505138625711486*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", "\[Rule]", "0.13179571663920933`"}], ",", 
    RowBox[{"y", "\[Rule]", "0.4662273476112026`"}]}], "}"}], "}"}]], "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.5051386164340377`*^9, 3.505138625711486*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Example 3.3.2",
 FontWeight->"Bold"]], "Subsubtitle",
 CellChangeTimes->{{3.5051388171955223`*^9, 3.5051388203817167`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Ae", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"187", ",", "790", ",", "5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"201", ",", "850", ",", "37"}], "}"}]}], "}"}]}], ")"}], "//", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"187", "790", "5"},
     {"201", "850", "37"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.5051388267384863`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"N", "[", 
   RowBox[{"RowReduce", "[", "Ae", "]"}], "]"}], "//", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1.`", "0.`", 
      RowBox[{"-", "156.125`"}]},
     {"0.`", "1.`", "36.9625`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.5051388306431365`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Aa", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"187", ",", "790", ",", "5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"201.1", ",", "850", ",", "37"}], "}"}]}], "}"}]}], ")"}], "//",
   "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"187", "790", "5"},
     {"201.1`", "850", "37"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.5051388343759823`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"N", "[", 
   RowBox[{"RowReduce", "[", "Aa", "]"}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.505138837921404*^9, 3.505138840435999*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1.`", "0.`", 
      RowBox[{"-", "308.39506172845057`"}]},
     {"0.`", "1.`", "73.00617283951931`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.5051388407639894`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{"N", "[", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"187", " ", "x"}], "+", 
       RowBox[{"790", " ", "y"}]}], "\[Equal]", "5"}], ",", "y"}], "]"}], 
   "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"y", "\[Rule]", 
    RowBox[{"0.006329113924050633`", "\[InvisibleSpace]", "-", 
     RowBox[{"0.23670886075949368`", " ", "x"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.505138845964983*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{"N", "[", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"201", " ", "x"}], "+", 
       RowBox[{"850", " ", "y"}]}], "\[Equal]", "37"}], ",", "y"}], "]"}], 
   "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"y", "\[Rule]", 
    RowBox[{"0.04352941176470588`", "\[InvisibleSpace]", "-", 
     RowBox[{"0.2364705882352941`", " ", "x"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.505138850306954*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Example 3.3.3",
 FontWeight->"Bold"]], "Subsubtitle",
 CellChangeTimes->{{3.50513885905337*^9, 3.50513886061523*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ae", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.23671", ",", "1", ",", "0.00633"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.23647", ",", "1", ",", "0.04353"}], "}"}]}], "}"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RAe", "=", 
   RowBox[{"RowReduce", "[", "Ae", "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExactSoln", "=", 
  RowBox[{"RAe", "[", 
   RowBox[{"[", 
    RowBox[{"All", ",", 
     RowBox[{"-", "1"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "154.9999999999964`"}], ",", "36.696379999999145`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5051388760776443`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.23671", ",", "1", ",", "0.00633"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.23647", "+", "R"}], ",", "1", ",", "0.04353"}], "}"}]}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.505138886620199*^9, 3.5051388867920036`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ApproxSoln", "=", 
  RowBox[{
   RowBox[{"RowReduce", "[", "As", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"All", ",", 
     RowBox[{"-", "1"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.026741582527142916`", "\[InvisibleSpace]", "-", 
    FractionBox["0.03720641797980651`", 
     RowBox[{"0.00023999999999999022`", "\[InvisibleSpace]", "-", 
      RowBox[{"1.`", " ", "R"}]}]], "+", 
    FractionBox[
     RowBox[{"0.026741582527142916`", " ", "R"}], 
     RowBox[{"0.00023999999999999022`", "\[InvisibleSpace]", "-", 
      RowBox[{"1.`", " ", "R"}]}]]}], ",", 
   FractionBox[
    RowBox[{"0.0103039863`", "\[InvisibleSpace]", "-", 
     RowBox[{"0.00633`", " ", 
      RowBox[{"(", 
       RowBox[{"0.23647`", "\[InvisibleSpace]", "+", "R"}], ")"}]}]}], 
    RowBox[{"0.00023999999999999022`", "\[InvisibleSpace]", "-", 
     RowBox[{"1.`", " ", "R"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.50513889018124*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ErrorFunc", "=", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"ExactSoln", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "-", 
        RowBox[{"ApproxSoln", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"ExactSoln", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "-", 
        RowBox[{"ApproxSoln", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "2"]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.505138900427041*^9, 3.505138910782173*^9}}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{"ErrorFunc", ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.3"}], ",", "0.3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"120", ",", "180"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}], "}"}]}], ",", 
   RowBox[{"AxesOrigin", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.3"}], ",", "120"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.505138921465296*^9, 3.505138929930577*^9}, {
  3.5051389614489117`*^9, 3.5051389723819313`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SolutionPlot", "[", "r_", "]"}], ":=", " ", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "originalsolution", ",", "currentsolution", ",", "r1solution", ",", 
      "distance", ",", "pointgraphics", ",", "errorplot", ",", " ", 
      "pointplot", ",", "x", ",", "y", ",", "r1"}], "}"}], ",", 
    RowBox[{
     RowBox[{"r1solution", "=", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y"}], "}"}], "/.", " ", 
       RowBox[{
        RowBox[{"Solve", "[", " ", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"23671", "/", "100000"}], "x"}], "+", "y"}], 
             "\[Equal]", 
             RowBox[{"633", "/", "100000"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"23647", "/", "100000"}], "+", "r1"}], ")"}], "x"}], 
              "+", "y"}], "\[Equal]", 
             RowBox[{"4353", "/", "100000"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "y"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}]}], ";", 
     RowBox[{"originalsolution", "=", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y"}], "}"}], "/.", 
       RowBox[{
        RowBox[{"Solve", "[", " ", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"23671", "/", "100000"}], "x"}], "+", "y"}], 
             "\[Equal]", 
             RowBox[{"633", "/", "100000"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"23647", "/", "100000"}], ")"}], "x"}], "+", "y"}], 
             "\[Equal]", 
             RowBox[{"4353", "/", "100000"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "y"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"currentsolution", "=", 
      RowBox[{"r1solution", "/.", " ", 
       RowBox[{"r1", "\[Rule]", "r"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"distance", "=", 
      RowBox[{"Norm", "[", 
       RowBox[{"r1solution", "-", "originalsolution"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"pointgraphics", "=", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Arrowheads", "[", ".1", "]"}], ",", 
         RowBox[{"PointSize", "[", ".04", "]"}], ",", "Red", ",", " ", 
         RowBox[{"Point", "[", "originalsolution", "]"}], ",", "Blue", ",", 
         RowBox[{"Point", "[", "currentsolution", "]"}], ",", " ", "Green", 
         ",", " ", 
         RowBox[{"Arrow", "[", 
          RowBox[{"{", 
           RowBox[{"originalsolution", ",", " ", "currentsolution"}], "}"}], 
          "]"}]}], "}"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"pointplot", "=", 
      RowBox[{"Show", "[", 
       RowBox[{"pointgraphics", ",", " ", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1000"}], ",", 
             RowBox[{"-", "150"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "250"}], "}"}]}], "}"}]}], ",", " ", 
        RowBox[{"Axes", "\[Rule]", "True"}], ",", "  ", 
        RowBox[{"AxesLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"x", ",", "y"}], "}"}]}], ",", " ", 
        RowBox[{"AspectRatio", "\[Rule]", 
         RowBox[{"2", "/", "3"}]}], ",", " ", 
        RowBox[{"ImageSize", "\[Rule]", "250"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Return", "[", 
      RowBox[{"Show", "[", 
       RowBox[{"GraphicsArray", "[", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"Show", "[", 
           RowBox[{"pointplot", ",", 
            RowBox[{"AxesOrigin", "\[Rule]", " ", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1000"}], ",", "0"}], "}"}]}]}], "]"}], "}"}], 
         "}"}], "]"}], "]"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.505140442951215*^9, 3.505140474204033*^9}, {
  3.505140510423567*^9, 3.5051405352102847`*^9}, {3.505140843271551*^9, 
  3.505140846020425*^9}, {3.505141138666133*^9, 3.505141262990189*^9}, {
  3.5051413073001575`*^9, 3.50514144939818*^9}}],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"SolutionPlot", "[", "r", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"r", ",", "0"}], "}"}], ",", "0", ",", ".0002", ",", 
     ".000001"}], "}"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "  ", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5051404973507986`*^9, 3.505140498537812*^9}, {
  3.505140542785306*^9, 3.505140544066031*^9}, {3.505141402464287*^9, 
  3.5051414034638777`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Example 3.3.4",
 FontWeight->"Bold"]], "Subsubtitle",
 CellChangeTimes->{{3.5051417070894613`*^9, 3.5051417089168377`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ae", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5.", ",", 
       RowBox[{"-", "2"}], ",", "8", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "9", ",", "11", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7", ",", "18.7", ",", "20"}], "}"}]}], "}"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RAe", "=", 
   RowBox[{"RowReduce", "[", "Ae", "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExactSoln", "=", 
  RowBox[{"RAe", "[", 
   RowBox[{"[", 
    RowBox[{"All", ",", 
     RowBox[{"-", "1"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"75.56410256410238`", ",", "61.41025641025627`", ",", 
   RowBox[{"-", "29.999999999999922`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5051417232078567`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Aa", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5.", ",", 
       RowBox[{"-", "2"}], ",", "8", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "9", ",", "11", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7", ",", "18.9", ",", "20"}], "}"}]}], "}"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RAa", "=", 
   RowBox[{"RowReduce", "[", "Aa", "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ApproxSoln", "=", 
  RowBox[{"RAa", "[", 
   RowBox[{"[", 
    RowBox[{"All", ",", 
     RowBox[{"-", "1"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"220.17948717948403`", ",", "182.94871794871534`", ",", 
   RowBox[{"-", "89.9999999999987`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5051417358433037`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"As", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"5.", ",", 
        RowBox[{"-", "2"}], ",", "8", ",", "15"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "9", ",", "11", ",", 
        RowBox[{"-", "4"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "7", ",", 
        RowBox[{"18.7", "+", "R"}], ",", "20"}], "}"}]}], "}"}]}], ")"}], "//",
   "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"5.`", 
      RowBox[{"-", "2"}], "8", "15"},
     {
      RowBox[{"-", "3"}], "9", "11", 
      RowBox[{"-", "4"}]},
     {"2", "7", 
      RowBox[{"18.7`", "\[InvisibleSpace]", "+", "R"}], "20"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.505141740450791*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ApproxSoln", "=", 
  RowBox[{
   RowBox[{"RowReduce", "[", "As", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"All", ",", 
     RowBox[{"-", "1"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"3.2564102564102564`", "\[InvisibleSpace]", "-", 
    FractionBox["4230.`", 
     RowBox[{
      RowBox[{"-", "58.5`"}], "+", 
      RowBox[{"195.`", " ", "R"}]}]]}], ",", 
   RowBox[{"0.6410256410256411`", "\[InvisibleSpace]", "-", 
    FractionBox["3555.`", 
     RowBox[{
      RowBox[{"-", "58.5`"}], "+", 
      RowBox[{"195.`", " ", "R"}]}]]}], ",", 
   FractionBox["1755.`", 
    RowBox[{
     RowBox[{"-", "58.5`"}], "+", 
     RowBox[{"195.`", " ", "R"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.5051417476978216`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ErrorFunc", "=", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"ExactSoln", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "-", 
        RowBox[{"ApproxSoln", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"ExactSoln", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "-", 
        RowBox[{"ApproxSoln", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"ExactSoln", "[", 
         RowBox[{"[", "3", "]"}], "]"}], "-", 
        RowBox[{"ApproxSoln", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], ")"}], "2"]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.505141757896767*^9, 3.5051417759831057`*^9}}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{"ErrorFunc", ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1000"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}], "}"}]}], ",", 
   RowBox[{"AxesOrigin", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}]}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", " ", 
    RowBox[{"1", "/", "3"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.505141780465644*^9, 3.5051417976304855`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SolutionPlot3D", "[", "r_", "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "originalsolution", ",", "currentsolution", ",", "r1solution", ",", 
      "distance", ",", "pointgraphics", ",", "errorplot", ",", "pointplot", 
      ",", "x", ",", "y", ",", "z", ",", "r1"}], "}"}], ",", 
    RowBox[{
     RowBox[{"r1solution", "=", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "z"}], "}"}], "/.", 
       RowBox[{
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"5", " ", "x"}], "-", 
              RowBox[{"2", " ", "y"}], "+", 
              RowBox[{"8", " ", "z"}]}], "\[Equal]", "15"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"-", "3"}], " ", "x"}], "+", 
              RowBox[{"9", " ", "y"}], "+", 
              RowBox[{"11", " ", "z"}]}], "\[Equal]", 
             RowBox[{"-", "4"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"2", " ", "x"}], "+", 
              RowBox[{"7", " ", "y"}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"18.7", "+", "r1"}], ")"}], " ", "z"}]}], "\[Equal]", 
             "20"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"originalsolution", "=", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "z"}], "}"}], "/.", 
       RowBox[{
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"5", " ", "x"}], "-", 
              RowBox[{"2", " ", "y"}], "+", 
              RowBox[{"8", " ", "z"}]}], "\[Equal]", "15"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"-", "3"}], " ", "x"}], "+", 
              RowBox[{"9", " ", "y"}], "+", 
              RowBox[{"11", " ", "z"}]}], "\[Equal]", 
             RowBox[{"-", "4"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"2", " ", "x"}], "+", 
              RowBox[{"7", " ", "y"}], "+", 
              RowBox[{"18.7", " ", "z"}]}], "\[Equal]", "20"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"currentsolution", "=", 
      RowBox[{"r1solution", "/.", 
       RowBox[{"r1", "\[Rule]", "r"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"distance", "=", 
      RowBox[{"Norm", "[", 
       RowBox[{"r1solution", "-", "originalsolution"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"pointgraphics", "=", 
      RowBox[{"Graphics3D", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Arrowheads", "[", ".1", "]"}], ",", 
         RowBox[{"PointSize", "[", ".05", "]"}], ",", 
         RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Red", ",", 
         RowBox[{"Point", "[", "originalsolution", "]"}], ",", "Blue", ",", 
         RowBox[{"Point", "[", "currentsolution", "]"}], ",", "Green", ",", 
         RowBox[{"Arrow", "[", 
          RowBox[{"{", 
           RowBox[{"originalsolution", ",", "currentsolution"}], "}"}], 
          "]"}]}], "}"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"pointplot", "=", 
      RowBox[{"Show", "[", 
       RowBox[{"pointgraphics", ",", 
        RowBox[{"PlotRange", "\[Rule]", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "500"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "500"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "200"}], ",", "0"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"Axes", "\[Rule]", " ", "True"}], ",", 
        RowBox[{"AspectRatio", "\[Rule]", " ", "1"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", " ", 
         RowBox[{"{", 
          RowBox[{"200", ",", "200"}], "}"}]}], ",", 
        RowBox[{"ViewPoint", "\[Rule]", " ", 
         RowBox[{"{", 
          RowBox[{"12", ",", 
           RowBox[{"-", "10"}], ",", "8"}], "}"}]}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Return", "[", 
      RowBox[{"Show", "[", 
       RowBox[{"GraphicsArray", "[", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"Show", "[", "pointplot", "]"}], "}"}], "}"}], "]"}], "]"}],
       "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5051418207147765`*^9, 3.5051418648997955`*^9}}],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"SolutionPlot3D", "[", "r", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"r", ",", "0"}], "}"}], ",", "0", ",", "0.25", ",", ".001"}], 
    "}"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", " ", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5051418722249193`*^9, 3.505141873177654*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Example 3.3.5",
 FontWeight->"Bold"]], "Subsubtitle",
 CellChangeTimes->{{3.505143050382773*^9, 3.505143051929014*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ae", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "2", ",", 
       RowBox[{"-", "4"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", 
       RowBox[{"-", "4"}], ",", "8.1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "1.95", ",", 
       RowBox[{"-", "4"}], ",", "3"}], "}"}]}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RAe", "=", 
   RowBox[{"RowReduce", "[", "Ae", "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExactSoln", "=", 
  RowBox[{"RAe", "[", 
   RowBox[{"[", 
    RowBox[{"All", ",", 
     RowBox[{"-", "1"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"54.00000000000013`", ",", 
   RowBox[{"-", "19.999999999999982`"}], ",", "30.000000000000107`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.50514307128046*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"As", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"3", ",", "2", ",", 
        RowBox[{"-", "4"}], ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "2", ",", 
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"4", "+", "R"}], ")"}]}], ",", 
        RowBox[{"1", "/", "2"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", 
        RowBox[{"(", 
         RowBox[{"2", "+", "S"}], ")"}], ",", 
        RowBox[{"-", "4"}], ",", "3"}], "}"}]}], "}"}]}], ")"}], "//", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"3", "2", 
      RowBox[{"-", "4"}], "2"},
     {"3", "2", 
      RowBox[{
       RowBox[{"-", "4"}], "-", "R"}], 
      FractionBox["1", "2"]},
     {"3", 
      RowBox[{"2", "+", "S"}], 
      RowBox[{"-", "4"}], "3"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.505143078699295*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"RAs", "=", 
   RowBox[{"RowReduce", "[", "As", "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ApproxSoln", "=", 
  RowBox[{
   RowBox[{"RowReduce", "[", "As", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"All", ",", 
     RowBox[{"-", "1"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["2", "3"], "+", 
    FractionBox["2", "R"], "-", 
    FractionBox["2", 
     RowBox[{"3", " ", "S"}]]}], ",", 
   FractionBox["1", "S"], ",", 
   FractionBox["3", 
    RowBox[{"2", " ", "R"}]]}], "}"}]], "Output",
 CellChangeTimes->{3.5051430878049383`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ApproxSoln", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"R", "\[Rule]", "0.05"}], ",", 
    RowBox[{"S", "\[Rule]", 
     RowBox[{"-", "0.05"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.505143093958667*^9, 3.5051431010495114`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"54.`", ",", 
   RowBox[{"-", "20.`"}], ",", "30.`"}], "}"}]], "Output",
 CellChangeTimes->{3.5051431087026253`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ErrorFunc", "=", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"ExactSoln", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "-", 
        RowBox[{"ApproxSoln", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"ExactSoln", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "-", 
        RowBox[{"ApproxSoln", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"ExactSoln", "[", 
         RowBox[{"[", "3", "]"}], "]"}], "-", 
        RowBox[{"ApproxSoln", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], ")"}], "2"]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5051431191514688`*^9, 3.505143135039858*^9}}],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{"ErrorFunc", ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", 
     RowBox[{"-", "0.3"}], ",", "0.3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"S", ",", 
     RowBox[{"-", "0.3"}], ",", "0.3"}], "}"}], ",", 
   RowBox[{"Mesh", "\[Rule]", " ", "None"}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", " ", 
    RowBox[{"2", "/", "3"}]}], ",", 
   RowBox[{"ClippingStyle", "\[Rule]", " ", "None"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.505143140373642*^9, 3.5051431491430106`*^9}}],

Cell[BoxData[
 RowBox[{"ContourPlot", "[", 
  RowBox[{"ErrorFunc", ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", "0.04", ",", "0.06"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"S", ",", 
     RowBox[{"-", "0.06"}], ",", 
     RowBox[{"-", "0.04"}]}], "}"}], ",", " ", 
   RowBox[{"Contours", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
     "0", ",", "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", 
      "7", ",", "8", ",", "9", ",", "10"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.505143166069931*^9, 3.5051431721096573`*^9}}]
}, Closed]]
}, Open  ]]
},
WindowSize->{1432, 783},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 310, 5, 83, "Title"],
Cell[880, 29, 314, 5, 49, "Subtitle"],
Cell[CellGroupData[{
Cell[1219, 38, 195, 3, 29, "Subsubtitle",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[1417, 43, 572, 18, 31, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[1992, 63, 315, 7, 30, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[2310, 72, 574, 18, 31, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[2887, 92, 317, 7, 30, "Output",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[3241, 104, 147, 2, 29, "Subsubtitle"],
Cell[CellGroupData[{
Cell[3413, 110, 300, 10, 31, "Input"],
Cell[3716, 122, 648, 18, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4401, 145, 128, 4, 31, "Input"],
Cell[4532, 151, 683, 19, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5252, 175, 302, 10, 31, "Input"],
Cell[5557, 187, 651, 18, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6245, 210, 194, 5, 31, "Input"],
Cell[6442, 217, 704, 19, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7183, 241, 269, 9, 31, "Input"],
Cell[7455, 252, 256, 6, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7748, 263, 270, 9, 31, "Input"],
Cell[8021, 274, 254, 6, 30, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[8324, 286, 141, 2, 29, "Subsubtitle"],
Cell[8468, 290, 270, 9, 31, "Input"],
Cell[8741, 301, 107, 3, 31, "Input"],
Cell[CellGroupData[{
Cell[8873, 308, 159, 5, 31, "Input"],
Cell[9035, 315, 174, 5, 30, "Output"]
}, Open  ]],
Cell[9224, 323, 368, 11, 31, "Input"],
Cell[CellGroupData[{
Cell[9617, 338, 196, 6, 31, "Input"],
Cell[9816, 346, 788, 18, 48, "Output"]
}, Open  ]],
Cell[10619, 367, 655, 20, 33, "Input"],
Cell[11277, 389, 826, 24, 52, "Input"],
Cell[12106, 415, 4523, 117, 352, "Input"],
Cell[16632, 534, 495, 12, 31, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[17164, 551, 147, 2, 29, "Subsubtitle"],
Cell[17314, 555, 425, 14, 31, "Input"],
Cell[17742, 571, 107, 3, 31, "Input"],
Cell[CellGroupData[{
Cell[17874, 578, 159, 5, 31, "Input"],
Cell[18036, 585, 198, 4, 30, "Output"]
}, Open  ]],
Cell[18249, 592, 425, 14, 31, "Input"],
Cell[18677, 608, 107, 3, 31, "Input"],
Cell[CellGroupData[{
Cell[18809, 615, 160, 5, 31, "Input"],
Cell[18972, 622, 198, 4, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19207, 631, 504, 16, 31, "Input"],
Cell[19714, 649, 797, 23, 71, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20548, 677, 196, 6, 31, "Input"],
Cell[20747, 685, 582, 17, 48, "Output"]
}, Open  ]],
Cell[21344, 705, 894, 27, 55, "Input"],
Cell[22241, 734, 834, 24, 52, "Input"],
Cell[23078, 760, 4766, 122, 352, "Input"],
Cell[27847, 884, 391, 10, 31, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[28275, 899, 143, 2, 29, "Subsubtitle"],
Cell[28421, 903, 466, 15, 31, "Input"],
Cell[28890, 920, 107, 3, 31, "Input"],
Cell[CellGroupData[{
Cell[29022, 927, 159, 5, 31, "Input"],
Cell[29184, 934, 199, 5, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29420, 944, 617, 20, 31, "Input"],
Cell[30040, 966, 820, 25, 81, "Output"]
}, Open  ]],
Cell[30875, 994, 107, 3, 31, "Input"],
Cell[CellGroupData[{
Cell[31007, 1001, 196, 6, 31, "Input"],
Cell[31206, 1009, 325, 11, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31568, 1025, 263, 7, 31, "Input"],
Cell[31834, 1034, 155, 4, 30, "Output"]
}, Open  ]],
Cell[32004, 1041, 894, 27, 55, "Input"],
Cell[32901, 1070, 527, 13, 52, "Input"],
Cell[33431, 1085, 557, 14, 52, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
